class DataGridTableStyle(Component,IComponent,IDisposable,IDataGridEditingService):
 """
 Represents the table drawn by the System.Windows.Forms.DataGrid control at run time.

 

 DataGridTableStyle(isDefaultTableStyle: bool)

 DataGridTableStyle()

 DataGridTableStyle(listManager: CurrencyManager)
 """
 def BeginEdit(self,gridColumn,rowNumber):
  """
  BeginEdit(self: DataGridTableStyle,gridColumn: DataGridColumnStyle,rowNumber: int) -> bool

  

   Requests an edit operation.

  

   gridColumn: The System.Windows.Forms.DataGridColumnStyle to edit.

   rowNumber: The number of the edited row.

   Returns: true,if the operation succeeds; otherwise,false.
  """
  pass
 def CreateGridColumn(self,*args):
  """
  CreateGridColumn(self: DataGridTableStyle,prop: PropertyDescriptor,isDefault: bool) -> DataGridColumnStyle

  

   Creates a System.Windows.Forms.DataGridColumnStyle using the specified property descriptor. 

    Specifies whether the System.Windows.Forms.DataGridColumnStyle is a default column style.

  

  

   prop: The System.ComponentModel.PropertyDescriptor used to create the column style object.

   isDefault: Specifies whether the System.Windows.Forms.DataGridColumnStyle is a default column style. This 

    parameter is read-only.

  

   Returns: The newly created System.Windows.Forms.DataGridColumnStyle.

  CreateGridColumn(self: DataGridTableStyle,prop: PropertyDescriptor) -> DataGridColumnStyle

  

   Creates a System.Windows.Forms.DataGridColumnStyle,using the specified property descriptor.

  

   prop: The System.ComponentModel.PropertyDescriptor used to create the column style object.

   Returns: The newly created System.Windows.Forms.DataGridColumnStyle.
  """
  pass
 def Dispose(self):
  """
  Dispose(self: DataGridTableStyle,disposing: bool)

   Disposes of the resources (other than memory) used by the 

    System.Windows.Forms.DataGridTableStyle.

  

  

   disposing: true to release both managed and unmanaged resources; false to release only unmanaged resources.
  """
  pass
 def EndEdit(self,gridColumn,rowNumber,shouldAbort):
  """
  EndEdit(self: DataGridTableStyle,gridColumn: DataGridColumnStyle,rowNumber: int,shouldAbort: bool) -> bool

  

   Requests an end to an edit operation.

  

   gridColumn: The System.Windows.Forms.DataGridColumnStyle to edit.

   rowNumber: The number of the edited row.

   shouldAbort: A value indicating whether the operation should be stopped; true if it should stop; otherwise,

    false.

  

   Returns: true if the edit operation ends successfully; otherwise,false.
  """
  pass
 def GetService(self,*args):
  """
  GetService(self: Component,service: Type) -> object

  

   Returns an object that represents a service provided by the System.ComponentModel.Component or 

    by its System.ComponentModel.Container.

  

  

   service: A service provided by the System.ComponentModel.Component.

   Returns: An System.Object that represents a service provided by the System.ComponentModel.Component,or 

    null if the System.ComponentModel.Component does not provide the specified service.
  """
  pass
 def MemberwiseClone(self,*args):
  """
  MemberwiseClone(self: MarshalByRefObject,cloneIdentity: bool) -> MarshalByRefObject

  

   Creates a shallow copy of the current System.MarshalByRefObject object.

  

   cloneIdentity: false to delete the current System.MarshalByRefObject object's identity,which will cause the 

    object to be assigned a new identity when it is marshaled across a remoting boundary. A value of 

    false is usually appropriate. true to copy the current System.MarshalByRefObject object's 

    identity to its clone,which will cause remoting client calls to be routed to the remote server 

    object.

  

   Returns: A shallow copy of the current System.MarshalByRefObject object.

  MemberwiseClone(self: object) -> object

  

   Creates a shallow copy of the current System.Object.

   Returns: A shallow copy of the current System.Object.
  """
  pass
 def OnAllowSortingChanged(self,*args):
  """
  OnAllowSortingChanged(self: DataGridTableStyle,e: EventArgs)

   Raises the System.Windows.Forms.DataGridTableStyle.AllowSortingChanged event.

  

   e: An System.EventArgs that contains the event data.
  """
  pass
 def OnAlternatingBackColorChanged(self,*args):
  """
  OnAlternatingBackColorChanged(self: DataGridTableStyle,e: EventArgs)

   Raises the System.Windows.Forms.DataGridTableStyle.AlternatingBackColorChanged event.

  

   e: An System.EventArgs that contains the event data.
  """
  pass
 def OnBackColorChanged(self,*args):
  """
  OnBackColorChanged(self: DataGridTableStyle,e: EventArgs)

   Raises the System.Windows.Forms.DataGridTableStyle.BackColorChanged event.

  

   e: An System.EventArgs that contains the event data.
  """
  pass
 def OnColumnHeadersVisibleChanged(self,*args):
  """
  OnColumnHeadersVisibleChanged(self: DataGridTableStyle,e: EventArgs)

   Raises the System.Windows.Forms.DataGridTableStyle.ColumnHeadersVisibleChanged event.

  

   e: An System.EventArgs that contains the event data.
  """
  pass
 def OnForeColorChanged(self,*args):
  """
  OnForeColorChanged(self: DataGridTableStyle,e: EventArgs)

   Raises the System.Windows.Forms.DataGridTableStyle.ForeColorChanged event.

  

   e: An System.EventArgs that contains the event data.
  """
  pass
 def OnGridLineColorChanged(self,*args):
  """
  OnGridLineColorChanged(self: DataGridTableStyle,e: EventArgs)

   Raises the System.Windows.Forms.DataGridTableStyle.GridLineColorChanged event.

  

   e: An System.EventArgs that contains the event data.
  """
  pass
 def OnGridLineStyleChanged(self,*args):
  """
  OnGridLineStyleChanged(self: DataGridTableStyle,e: EventArgs)

   Raises the System.Windows.Forms.DataGridTableStyle.GridLineStyleChanged event.

  

   e: An System.EventArgs that contains the event data.
  """
  pass
 def OnHeaderBackColorChanged(self,*args):
  """
  OnHeaderBackColorChanged(self: DataGridTableStyle,e: EventArgs)

   Raises the System.Windows.Forms.DataGridTableStyle.HeaderBackColorChanged event.

  

   e: An System.EventArgs that contains the event data.
  """
  pass
 def OnHeaderFontChanged(self,*args):
  """
  OnHeaderFontChanged(self: DataGridTableStyle,e: EventArgs)

   Raises the System.Windows.Forms.DataGridTableStyle.HeaderFontChanged event.

  

   e: An System.EventArgs that contains the event data.
  """
  pass
 def OnHeaderForeColorChanged(self,*args):
  """
  OnHeaderForeColorChanged(self: DataGridTableStyle,e: EventArgs)

   Raises the System.Windows.Forms.DataGridTableStyle.HeaderForeColorChanged event.

  

   e: An System.EventArgs that contains the event data.
  """
  pass
 def OnLinkColorChanged(self,*args):
  """
  OnLinkColorChanged(self: DataGridTableStyle,e: EventArgs)

   Raises the System.Windows.Forms.DataGridTableStyle.LinkColorChanged event.

  

   e: An System.EventArgs that contains the event data.
  """
  pass
 def OnLinkHoverColorChanged(self,*args):
  """
  OnLinkHoverColorChanged(self: DataGridTableStyle,e: EventArgs)

   Raises the LinkHoverColorChanged event.

  

   e: An System.EventArgs that contains the event data.
  """
  pass
 def OnMappingNameChanged(self,*args):
  """
  OnMappingNameChanged(self: DataGridTableStyle,e: EventArgs)

   Raises the System.Windows.Forms.DataGridTableStyle.MappingNameChanged event

  

   e: An System.EventArgs that contains the event data.
  """
  pass
 def OnPreferredColumnWidthChanged(self,*args):
  """
  OnPreferredColumnWidthChanged(self: DataGridTableStyle,e: EventArgs)

   Raises the System.Windows.Forms.DataGridTableStyle.PreferredColumnWidthChanged event.

  

   e: An System.EventArgs that contains the event data.
  """
  pass
 def OnPreferredRowHeightChanged(self,*args):
  """
  OnPreferredRowHeightChanged(self: DataGridTableStyle,e: EventArgs)

   Raises the System.Windows.Forms.DataGridTableStyle.PreferredRowHeightChanged event.

  

   e: An System.EventArgs that contains the event data.
  """
  pass
 def OnReadOnlyChanged(self,*args):
  """
  OnReadOnlyChanged(self: DataGridTableStyle,e: EventArgs)

   Raises the System.Windows.Forms.DataGridTableStyle.ReadOnlyChanged event.

  

   e: An System.EventArgs that contains the event data.
  """
  pass
 def OnRowHeadersVisibleChanged(self,*args):
  """
  OnRowHeadersVisibleChanged(self: DataGridTableStyle,e: EventArgs)

   Raises the System.Windows.Forms.DataGridTableStyle.RowHeadersVisibleChanged event.

  

   e: An System.EventArgs that contains the event data.
  """
  pass
 def OnRowHeaderWidthChanged(self,*args):
  """
  OnRowHeaderWidthChanged(self: DataGridTableStyle,e: EventArgs)

   Raises the System.Windows.Forms.DataGridTableStyle.RowHeaderWidthChanged event.

  

   e: An System.EventArgs that contains the event data.
  """
  pass
 def OnSelectionBackColorChanged(self,*args):
  """
  OnSelectionBackColorChanged(self: DataGridTableStyle,e: EventArgs)

   Raises the System.Windows.Forms.DataGridTableStyle.SelectionBackColorChanged event.

  

   e: An System.EventArgs that contains the event data.
  """
  pass
 def OnSelectionForeColorChanged(self,*args):
  """
  OnSelectionForeColorChanged(self: DataGridTableStyle,e: EventArgs)

   Raises the System.Windows.Forms.DataGridTableStyle.SelectionForeColorChanged event.

  

   e: An System.EventArgs that contains the event data.
  """
  pass
 def ResetAlternatingBackColor(self):
  """
  ResetAlternatingBackColor(self: DataGridTableStyle)

   Resets the System.Windows.Forms.DataGridTableStyle.AlternatingBackColor property to its default 

    value.
  """
  pass
 def ResetBackColor(self):
  """
  ResetBackColor(self: DataGridTableStyle)

   Resets the System.Windows.Forms.DataGridTableStyle.BackColor property to its default value.
  """
  pass
 def ResetForeColor(self):
  """
  ResetForeColor(self: DataGridTableStyle)

   Resets the System.Windows.Forms.DataGridTableStyle.ForeColor property to its default value.
  """
  pass
 def ResetGridLineColor(self):
  """
  ResetGridLineColor(self: DataGridTableStyle)

   Resets the System.Windows.Forms.DataGridTableStyle.GridLineColor property to its default value.
  """
  pass
 def ResetHeaderBackColor(self):
  """
  ResetHeaderBackColor(self: DataGridTableStyle)

   Resets the System.Windows.Forms.DataGridTableStyle.HeaderBackColor property to its default value.
  """
  pass
 def ResetHeaderFont(self):
  """
  ResetHeaderFont(self: DataGridTableStyle)

   Resets the System.Windows.Forms.DataGridTableStyle.HeaderFont property to its default value.
  """
  pass
 def ResetHeaderForeColor(self):
  """
  ResetHeaderForeColor(self: DataGridTableStyle)

   Resets the System.Windows.Forms.DataGridTableStyle.HeaderForeColor property to its default value.
  """
  pass
 def ResetLinkColor(self):
  """
  ResetLinkColor(self: DataGridTableStyle)

   Resets the System.Windows.Forms.DataGridTableStyle.LinkColor property to its default value.
  """
  pass
 def ResetLinkHoverColor(self):
  """
  ResetLinkHoverColor(self: DataGridTableStyle)

   Resets the System.Windows.Forms.DataGridTableStyle.LinkHoverColor property to its default value.
  """
  pass
 def ResetSelectionBackColor(self):
  """
  ResetSelectionBackColor(self: DataGridTableStyle)

   Resets the System.Windows.Forms.DataGridTableStyle.SelectionBackColor property to its default 

    value.
  """
  pass
 def ResetSelectionForeColor(self):
  """
  ResetSelectionForeColor(self: DataGridTableStyle)

   Resets the System.Windows.Forms.DataGridTableStyle.SelectionForeColor property to its default 

    value.
  """
  pass
 def ShouldSerializeAlternatingBackColor(self,*args):
  """
  ShouldSerializeAlternatingBackColor(self: DataGridTableStyle) -> bool

  

   Indicates whether the System.Windows.Forms.DataGridTableStyle.AlternatingBackColor property 

    should be persisted.

  

   Returns: true if the property value has changed from its default; otherwise,false.
  """
  pass
 def ShouldSerializeBackColor(self,*args):
  """
  ShouldSerializeBackColor(self: DataGridTableStyle) -> bool

  

   Indicates whether the System.Windows.Forms.DataGridTableStyle.BackColor property should be 

    persisted.

  

   Returns: true if the property value has changed from its default; otherwise,false.
  """
  pass
 def ShouldSerializeForeColor(self,*args):
  """
  ShouldSerializeForeColor(self: DataGridTableStyle) -> bool

  

   Indicates whether the System.Windows.Forms.DataGridTableStyle.ForeColor property should be 

    persisted.

  

   Returns: true if the property value has changed from its default; otherwise,false.
  """
  pass
 def ShouldSerializeGridLineColor(self,*args):
  """
  ShouldSerializeGridLineColor(self: DataGridTableStyle) -> bool

  

   Indicates whether the System.Windows.Forms.DataGridTableStyle.GridLineColor property should be 

    persisted.

  

   Returns: true if the property value has changed from its default; otherwise,false.
  """
  pass
 def ShouldSerializeHeaderBackColor(self,*args):
  """
  ShouldSerializeHeaderBackColor(self: DataGridTableStyle) -> bool

  

   Indicates whether the System.Windows.Forms.DataGridTableStyle.HeaderBackColor property should be 

    persisted.

  

   Returns: true if the property value has changed from its default; otherwise,false.
  """
  pass
 def ShouldSerializeHeaderForeColor(self,*args):
  """
  ShouldSerializeHeaderForeColor(self: DataGridTableStyle) -> bool

  

   Indicates whether the System.Windows.Forms.DataGridTableStyle.HeaderForeColor property should be 

    persisted.

  

   Returns: true if the property value has changed from its default; otherwise,false.
  """
  pass
 def ShouldSerializeLinkColor(self,*args):
  """
  ShouldSerializeLinkColor(self: DataGridTableStyle) -> bool

  

   Indicates whether the System.Windows.Forms.DataGridTableStyle.LinkColor property should be 

    persisted.

  

   Returns: true if the property value has changed from its default; otherwise,false.
  """
  pass
 def ShouldSerializeLinkHoverColor(self,*args):
  """
  ShouldSerializeLinkHoverColor(self: DataGridTableStyle) -> bool

  

   Indicates whether the System.Windows.Forms.DataGridTableStyle.LinkHoverColor property should be 

    persisted.

  

   Returns: true if the property value has changed from its default; otherwise,false.
  """
  pass
 def ShouldSerializePreferredRowHeight(self,*args):
  """
  ShouldSerializePreferredRowHeight(self: DataGridTableStyle) -> bool

  

   Indicates whether the System.Windows.Forms.DataGridTableStyle.PreferredRowHeight property should 

    be persisted.

  

   Returns: true if the property value has changed from its default; otherwise,false.
  """
  pass
 def ShouldSerializeSelectionBackColor(self,*args):
  """
  ShouldSerializeSelectionBackColor(self: DataGridTableStyle) -> bool

  

   Indicates whether the System.Windows.Forms.DataGridTableStyle.SelectionBackColor property should 

    be persisted.

  

   Returns: true if the property value has changed from its default; otherwise,false.
  """
  pass
 def ShouldSerializeSelectionForeColor(self,*args):
  """
  ShouldSerializeSelectionForeColor(self: DataGridTableStyle) -> bool

  

   Indicates whether the System.Windows.Forms.DataGridTableStyle.SelectionForeColor property should 

    be persisted.

  

   Returns: true if the property value has changed from its default; otherwise,false.
  """
  pass
 def __enter__(self,*args):
  """
  __enter__(self: IDisposable) -> object

  

   Provides the implementation of __enter__ for objects which implement IDisposable.
  """
  pass
 def __exit__(self,*args):
  """
  __exit__(self: IDisposable,exc_type: object,exc_value: object,exc_back: object)

   Provides the implementation of __exit__ for objects which implement IDisposable.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,*__args):
  """
  __new__(cls: type,isDefaultTableStyle: bool)

  __new__(cls: type)

  __new__(cls: type,listManager: CurrencyManager)
  """
  pass
 def __str__(self,*args):
  pass
 AllowSorting=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Indicates whether sorting is allowed on the grid table when this System.Windows.Forms.DataGridTableStyle is used.



Get: AllowSorting(self: DataGridTableStyle) -> bool



Set: AllowSorting(self: DataGridTableStyle)=value

"""

 AlternatingBackColor=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the background color of odd-numbered rows of the grid.



Get: AlternatingBackColor(self: DataGridTableStyle) -> Color



Set: AlternatingBackColor(self: DataGridTableStyle)=value

"""

 BackColor=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the background color of even-numbered rows of the grid.



Get: BackColor(self: DataGridTableStyle) -> Color



Set: BackColor(self: DataGridTableStyle)=value

"""

 CanRaiseEvents=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether the component can raise an event.



"""

 ColumnHeadersVisible=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether column headers are visible.



Get: ColumnHeadersVisible(self: DataGridTableStyle) -> bool



Set: ColumnHeadersVisible(self: DataGridTableStyle)=value

"""

 DataGrid=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the System.Windows.Forms.DataGrid control for the drawn table.



Get: DataGrid(self: DataGridTableStyle) -> DataGrid



Set: DataGrid(self: DataGridTableStyle)=value

"""

 DesignMode=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value that indicates whether the System.ComponentModel.Component is currently in design mode.



"""

 Events=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the list of event handlers that are attached to this System.ComponentModel.Component.



"""

 ForeColor=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the foreground color of the grid table.



Get: ForeColor(self: DataGridTableStyle) -> Color



Set: ForeColor(self: DataGridTableStyle)=value

"""

 GridColumnStyles=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the collection of columns drawn for this table.



Get: GridColumnStyles(self: DataGridTableStyle) -> GridColumnStylesCollection



"""

 GridLineColor=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the color of grid lines.



Get: GridLineColor(self: DataGridTableStyle) -> Color



Set: GridLineColor(self: DataGridTableStyle)=value

"""

 GridLineStyle=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the style of grid lines.



Get: GridLineStyle(self: DataGridTableStyle) -> DataGridLineStyle



Set: GridLineStyle(self: DataGridTableStyle)=value

"""

 HeaderBackColor=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the background color of headers.



Get: HeaderBackColor(self: DataGridTableStyle) -> Color



Set: HeaderBackColor(self: DataGridTableStyle)=value

"""

 HeaderFont=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the font used for header captions.



Get: HeaderFont(self: DataGridTableStyle) -> Font



Set: HeaderFont(self: DataGridTableStyle)=value

"""

 HeaderForeColor=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the foreground color of headers.



Get: HeaderForeColor(self: DataGridTableStyle) -> Color



Set: HeaderForeColor(self: DataGridTableStyle)=value

"""

 LinkColor=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the color of link text.



Get: LinkColor(self: DataGridTableStyle) -> Color



Set: LinkColor(self: DataGridTableStyle)=value

"""

 LinkHoverColor=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the color displayed when hovering over link text.



Get: LinkHoverColor(self: DataGridTableStyle) -> Color



Set: LinkHoverColor(self: DataGridTableStyle)=value

"""

 MappingName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the name used to map this table to a specific data source.



Get: MappingName(self: DataGridTableStyle) -> str



Set: MappingName(self: DataGridTableStyle)=value

"""

 PreferredColumnWidth=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the width used to create columns when a new grid is displayed.



Get: PreferredColumnWidth(self: DataGridTableStyle) -> int



Set: PreferredColumnWidth(self: DataGridTableStyle)=value

"""

 PreferredRowHeight=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the height used to create a row when a new grid is displayed.



Get: PreferredRowHeight(self: DataGridTableStyle) -> int



Set: PreferredRowHeight(self: DataGridTableStyle)=value

"""

 ReadOnly=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether columns can be edited.



Get: ReadOnly(self: DataGridTableStyle) -> bool



Set: ReadOnly(self: DataGridTableStyle)=value

"""

 RowHeadersVisible=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether row headers are visible.



Get: RowHeadersVisible(self: DataGridTableStyle) -> bool



Set: RowHeadersVisible(self: DataGridTableStyle)=value

"""

 RowHeaderWidth=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the width of row headers.



Get: RowHeaderWidth(self: DataGridTableStyle) -> int



Set: RowHeaderWidth(self: DataGridTableStyle)=value

"""

 SelectionBackColor=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the background color of selected cells.



Get: SelectionBackColor(self: DataGridTableStyle) -> Color



Set: SelectionBackColor(self: DataGridTableStyle)=value

"""

 SelectionForeColor=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the foreground color of selected cells.



Get: SelectionForeColor(self: DataGridTableStyle) -> Color



Set: SelectionForeColor(self: DataGridTableStyle)=value

"""


 AllowSortingChanged=None
 AlternatingBackColorChanged=None
 BackColorChanged=None
 ColumnHeadersVisibleChanged=None
 DefaultTableStyle=None
 ForeColorChanged=None
 GridLineColorChanged=None
 GridLineStyleChanged=None
 HeaderBackColorChanged=None
 HeaderFontChanged=None
 HeaderForeColorChanged=None
 LinkColorChanged=None
 LinkHoverColorChanged=None
 MappingNameChanged=None
 PreferredColumnWidthChanged=None
 PreferredRowHeightChanged=None
 ReadOnlyChanged=None
 RowHeadersVisibleChanged=None
 RowHeaderWidthChanged=None
 SelectionBackColorChanged=None
 SelectionForeColorChanged=None




class TabRenderer(object):
 """ Provides methods used to render a tab control with visual styles. This class cannot be inherited. """
 @staticmethod
 def DrawTabItem(g,bounds,*__args):
  """
  DrawTabItem(g: Graphics,bounds: Rectangle,image: Image,imageRectangle: Rectangle,focused: bool,state: TabItemState)

   Draws a tab in the specified state and bounds,with the specified image,and with an optional 

    focus rectangle.

  

  

   g: The System.Drawing.Graphics used to draw the tab.

   bounds: The System.Drawing.Rectangle that specifies the bounds of the tab.

   image: The System.Drawing.Image to draw in the tab.

   imageRectangle: The System.Drawing.Rectangle that specifies the bounds of image.

   focused: true to draw a focus rectangle; otherwise,false.

   state: One of the System.Windows.Forms.VisualStyles.TabItemState values that specifies the visual state 

    of the tab.

  

  DrawTabItem(g: Graphics,bounds: Rectangle,tabItemText: str,font: Font,flags: TextFormatFlags,focused: bool,state: TabItemState)

   Draws a tab in the specified state and bounds,with the specified text and text formatting,and 

    with an optional focus rectangle.

  

  

   g: The System.Drawing.Graphics used to draw the tab.

   bounds: The System.Drawing.Rectangle that specifies the bounds of the tab.

   tabItemText: The System.String to draw in the tab.

   font: The System.Drawing.Font to apply to tabItemText.

   flags: A bitwise combination of the System.Windows.Forms.TextFormatFlags values.

   focused: true to draw a focus rectangle; otherwise,false.

   state: One of the System.Windows.Forms.VisualStyles.TabItemState values that specifies the visual state 

    of the tab.

  

  DrawTabItem(g: Graphics,bounds: Rectangle,tabItemText: str,font: Font,flags: TextFormatFlags,image: Image,imageRectangle: Rectangle,focused: bool,state: TabItemState)

   Draws a tab in the specified state and bounds; with the specified text,text formatting,and 

    image; and with an optional focus rectangle.

  

  

   g: The System.Drawing.Graphics used to draw the tab.

   bounds: The System.Drawing.Rectangle that specifies the bounds of the tab.

   tabItemText: The System.String to draw in the tab.

   font: The System.Drawing.Font to apply to tabItemText.

   flags: A bitwise combination of the System.Windows.Forms.TextFormatFlags values.

   image: The System.Drawing.Image to draw in the tab.

   imageRectangle: The System.Drawing.Rectangle that specifies the bounds of image.

   focused: true to draw a focus rectangle; otherwise,false.

   state: One of the System.Windows.Forms.VisualStyles.TabItemState values that specifies the visual state 

    of the tab.

  

  DrawTabItem(g: Graphics,bounds: Rectangle,tabItemText: str,font: Font,image: Image,imageRectangle: Rectangle,focused: bool,state: TabItemState)

   Draws a tab in the specified state and bounds,with the specified text and image,and with an 

    optional focus rectangle.

  

  

   g: The System.Drawing.Graphics used to draw the tab.

   bounds: The System.Drawing.Rectangle that specifies the bounds of the tab.

   tabItemText: The System.String to draw in the tab.

   font: The System.Drawing.Font to apply to tabItemText.

   image: The System.Drawing.Image to draw in the tab.

   imageRectangle: The System.Drawing.Rectangle that specifies the bounds of image.

   focused: true to draw a focus rectangle; otherwise,false.

   state: One of the System.Windows.Forms.VisualStyles.TabItemState values that specifies the visual state 

    of the tab.

  

  DrawTabItem(g: Graphics,bounds: Rectangle,focused: bool,state: TabItemState)

   Draws a tab in the specified state and bounds,and with an optional focus rectangle.

  

   g: The System.Drawing.Graphics used to draw the tab.

   bounds: The System.Drawing.Rectangle that specifies the bounds of the tab.

   focused: true to draw a focus rectangle; otherwise,false.

   state: One of the System.Windows.Forms.VisualStyles.TabItemState values that specifies the visual state 

    of the tab.

  

  DrawTabItem(g: Graphics,bounds: Rectangle,state: TabItemState)

   Draws a tab in the specified state and bounds.

  

   g: The System.Drawing.Graphics used to draw the tab.

   bounds: The System.Drawing.Rectangle that specifies the bounds of the tab.

   state: One of the System.Windows.Forms.VisualStyles.TabItemState values that specifies the visual state 

    of the tab.

  

  DrawTabItem(g: Graphics,bounds: Rectangle,tabItemText: str,font: Font,focused: bool,state: TabItemState)

   Draws a tab in the specified state and bounds,with the specified text,and with an optional 

    focus rectangle.

  

  

   g: The System.Drawing.Graphics used to draw the tab.

   bounds: The System.Drawing.Rectangle that specifies the bounds of the tab.

   tabItemText: The System.String to draw in the tab.

   font: The System.Drawing.Font to apply to tabItemText.

   focused: true to draw a focus rectangle; otherwise,false.

   state: One of the System.Windows.Forms.VisualStyles.TabItemState values that specifies the visual state 

    of the tab.

  

  DrawTabItem(g: Graphics,bounds: Rectangle,tabItemText: str,font: Font,state: TabItemState)

   Draws a tab in the specified state and bounds,and with the specified text.

  

   g: The System.Drawing.Graphics used to draw the tab.

   bounds: The System.Drawing.Rectangle that specifies the bounds of the tab.

   tabItemText: The System.String to draw in the tab.

   font: The System.Drawing.Font to apply to tabItemText.

   state: One of the System.Windows.Forms.VisualStyles.TabItemState values that specifies the visual state 

    of the tab.
  """
  pass
 @staticmethod
 def DrawTabPage(g,bounds):
  """
  DrawTabPage(g: Graphics,bounds: Rectangle)

   Draws a tab page in the specified bounds.

  

   g: The System.Drawing.Graphics used to draw the tab page.

   bounds: The System.Drawing.Rectangle that specifies the bounds of the tab page.
  """
  pass
 IsSupported=True




from typing import Tuple, Set, Iterable, List


class IPipeFittingAndAccessoryPressureDropUIServer:
    def GetDBServerId(self) -> Guid: ...
    def ShowSettings(self, data: PipeFittingAndAccessoryPressureDropUIData) -> bool: ...


class PipeFittingAndAccessoryPressureDropUIDataItem:
    @property
    def IsValidObject(self) -> bool: ...
    def GetEntity(self) -> Entity: ...
    def SetEntity(self, entity: Entity) -> None: ...
    def GetPipeFittingAndAccessoryData(self) -> PipeFittingAndAccessoryData: ...
    def Dispose(self) -> None: ...


class PipeFittingAndAccessoryPressureDropUIData:
    @property
    def IsValidObject(self) -> bool: ...
    def GetUnits(self) -> Units: ...
    def GetUIDataItems(self) -> List[PipeFittingAndAccessoryPressureDropUIDataItem]: ...
    def Dispose(self) -> None: ...



class LoaderOptimizationAttribute(Attribute,_Attribute):
 """
 Used to set the default loader optimization policy for the main method of an executable application.

 

 LoaderOptimizationAttribute(value: Byte)

 LoaderOptimizationAttribute(value: LoaderOptimization)
 """
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,value):
  """
  __new__(cls: type,value: Byte)

  __new__(cls: type,value: LoaderOptimization)
  """
  pass
 Value=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the current System.LoaderOptimization value for this instance.



Get: Value(self: LoaderOptimizationAttribute) -> LoaderOptimization



"""





class FtpStatusCode(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies the status codes returned for a File Transfer Protocol (FTP) operation.

 

 enum FtpStatusCode,values: AccountNeeded (532),ActionAbortedLocalProcessingError (451),ActionAbortedUnknownPageType (551),ActionNotTakenFilenameNotAllowed (553),ActionNotTakenFileUnavailable (550),ActionNotTakenFileUnavailableOrBusy (450),ActionNotTakenInsufficientSpace (452),ArgumentSyntaxError (501),BadCommandSequence (503),CantOpenData (425),ClosingControl (221),ClosingData (226),CommandExtraneous (202),CommandNotImplemented (502),CommandOK (200),CommandSyntaxError (500),ConnectionClosed (426),DataAlreadyOpen (125),DirectoryStatus (212),EnteringPassive (227),FileActionAborted (552),FileActionOK (250),FileCommandPending (350),FileStatus (213),LoggedInProceed (230),NeedLoginAccount (332),NotLoggedIn (530),OpeningData (150),PathnameCreated (257),RestartMarker (110),SendPasswordCommand (331),SendUserCommand (220),ServerWantsSecureSession (234),ServiceNotAvailable (421),ServiceTemporarilyNotAvailable (120),SystemType (215),Undefined (0)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 AccountNeeded=None
 ActionAbortedLocalProcessingError=None
 ActionAbortedUnknownPageType=None
 ActionNotTakenFilenameNotAllowed=None
 ActionNotTakenFileUnavailable=None
 ActionNotTakenFileUnavailableOrBusy=None
 ActionNotTakenInsufficientSpace=None
 ArgumentSyntaxError=None
 BadCommandSequence=None
 CantOpenData=None
 ClosingControl=None
 ClosingData=None
 CommandExtraneous=None
 CommandNotImplemented=None
 CommandOK=None
 CommandSyntaxError=None
 ConnectionClosed=None
 DataAlreadyOpen=None
 DirectoryStatus=None
 EnteringPassive=None
 FileActionAborted=None
 FileActionOK=None
 FileCommandPending=None
 FileStatus=None
 LoggedInProceed=None
 NeedLoginAccount=None
 NotLoggedIn=None
 OpeningData=None
 PathnameCreated=None
 RestartMarker=None
 SendPasswordCommand=None
 SendUserCommand=None
 ServerWantsSecureSession=None
 ServiceNotAvailable=None
 ServiceTemporarilyNotAvailable=None
 SystemType=None
 Undefined=None
 value__=None




""" rpw.db modules

Import all class so they are available in the .db namespace
wrapper classes stay available in rpw.db

"""

import rpw.db

from rpw.db.element import Element
from rpw.db.family import FamilyInstance, FamilySymbol, Family
from rpw.db.category import Category

from rpw.db.wall import Wall, WallType, WallKind, WallCategory
from rpw.db.assembly import AssemblyInstance, AssemblyType

from rpw.db.spatial_element import Room, Area, AreaScheme

from rpw.db.view import View, ViewPlan, ViewSheet, ViewSection
from rpw.db.view import ViewSchedule, View3D
from rpw.db.view import ViewFamilyType
from rpw.db.view import ViewFamily, ViewType, ViewPlanType  # Enums

from rpw.db.pattern import LinePatternElement, FillPatternElement

from rpw.db.parameter import Parameter, ParameterSet
from rpw.db.builtins import BicEnum, BipEnum

from rpw.db.xyz import XYZ
from rpw.db.curve import Curve, Line, Ellipse, Circle, Arc
from rpw.db.transform import Transform
from rpw.db.bounding_box import BoundingBox

from rpw.db.reference import Reference

from rpw.db.collection import ElementSet, ElementCollection
from rpw.db.collection import XyzCollection

from rpw.db.collector import Collector, ParameterFilter
from rpw.db.transaction import Transaction, TransactionGroup

__all__ = [cls for cls in locals().values() if isinstance(cls, type)]



class MenuItem(Menu,IComponent,IDisposable):
 """
 Represents an individual item that is displayed within a System.Windows.Forms.MainMenu or System.Windows.Forms.ContextMenu. Although System.Windows.Forms.ToolStripMenuItem replaces and adds functionality to the System.Windows.Forms.MenuItem control of previous versions,System.Windows.Forms.MenuItem is retained for both backward compatibility and future use if you choose.

 

 MenuItem()

 MenuItem(text: str)

 MenuItem(text: str,onClick: EventHandler)

 MenuItem(text: str,onClick: EventHandler,shortcut: Shortcut)

 MenuItem(text: str,items: Array[MenuItem])

 MenuItem(mergeType: MenuMerge,mergeOrder: int,shortcut: Shortcut,text: str,onClick: EventHandler,onPopup: EventHandler,onSelect: EventHandler,items: Array[MenuItem])
 """
 def CloneMenu(self):
  """
  CloneMenu(self: MenuItem) -> MenuItem

  

   Creates a copy of the current System.Windows.Forms.MenuItem.

   Returns: A System.Windows.Forms.MenuItem that represents the duplicated menu item.
  """
  pass
 def CreateMenuHandle(self,*args):
  """
  CreateMenuHandle(self: Menu) -> IntPtr

  

   Creates a new handle to the System.Windows.Forms.Menu.

   Returns: A handle to the menu if the method succeeds; otherwise,null.
  """
  pass
 def Dispose(self):
  """
  Dispose(self: MenuItem,disposing: bool)

   Disposes of the resources (other than memory) used by the System.Windows.Forms.MenuItem.

  

   disposing: true to release both managed and unmanaged resources; false to release only unmanaged resources.
  """
  pass
 def FindMergePosition(self,*args):
  """
  FindMergePosition(self: Menu,mergeOrder: int) -> int

  

   Returns the position at which a menu item should be inserted into the menu.

  

   mergeOrder: The merge order position for the menu item to be merged.

   Returns: The position at which a menu item should be inserted into the menu.
  """
  pass
 def GetService(self,*args):
  """
  GetService(self: Component,service: Type) -> object

  

   Returns an object that represents a service provided by the System.ComponentModel.Component or 

    by its System.ComponentModel.Container.

  

  

   service: A service provided by the System.ComponentModel.Component.

   Returns: An System.Object that represents a service provided by the System.ComponentModel.Component,or 

    null if the System.ComponentModel.Component does not provide the specified service.
  """
  pass
 def MemberwiseClone(self,*args):
  """
  MemberwiseClone(self: MarshalByRefObject,cloneIdentity: bool) -> MarshalByRefObject

  

   Creates a shallow copy of the current System.MarshalByRefObject object.

  

   cloneIdentity: false to delete the current System.MarshalByRefObject object's identity,which will cause the 

    object to be assigned a new identity when it is marshaled across a remoting boundary. A value of 

    false is usually appropriate. true to copy the current System.MarshalByRefObject object's 

    identity to its clone,which will cause remoting client calls to be routed to the remote server 

    object.

  

   Returns: A shallow copy of the current System.MarshalByRefObject object.

  MemberwiseClone(self: object) -> object

  

   Creates a shallow copy of the current System.Object.

   Returns: A shallow copy of the current System.Object.
  """
  pass
 def MergeMenu(self,*__args):
  """
  MergeMenu(self: MenuItem,itemSrc: MenuItem)

   Merges another menu item with this menu item.

  

   itemSrc: A System.Windows.Forms.MenuItem that specifies the menu item to merge with this one.

  MergeMenu(self: MenuItem) -> MenuItem

  

   Merges this System.Windows.Forms.MenuItem with another System.Windows.Forms.MenuItem and returns 

    the resulting merged System.Windows.Forms.MenuItem.

  

   Returns: A System.Windows.Forms.MenuItem that represents the merged menu item.
  """
  pass
 def OnClick(self,*args):
  """
  OnClick(self: MenuItem,e: EventArgs)

   Raises the System.Windows.Forms.MenuItem.Click event.

  

   e: An System.EventArgs that contains the event data.
  """
  pass
 def OnDrawItem(self,*args):
  """
  OnDrawItem(self: MenuItem,e: DrawItemEventArgs)

   Raises the System.Windows.Forms.MenuItem.DrawItem event.

  

   e: A System.Windows.Forms.DrawItemEventArgs that contains the event data.
  """
  pass
 def OnInitMenuPopup(self,*args):
  """
  OnInitMenuPopup(self: MenuItem,e: EventArgs)

   Raises the System.Windows.Forms.MenuItem.Popup event.

  

   e: An System.EventArgs that contains the event data.
  """
  pass
 def OnMeasureItem(self,*args):
  """
  OnMeasureItem(self: MenuItem,e: MeasureItemEventArgs)

   Raises the System.Windows.Forms.MenuItem.MeasureItem event.

  

   e: A System.Windows.Forms.MeasureItemEventArgs that contains the event data.
  """
  pass
 def OnPopup(self,*args):
  """
  OnPopup(self: MenuItem,e: EventArgs)

   Raises the System.Windows.Forms.MenuItem.Popup event.

  

   e: An System.EventArgs that contains the event data.
  """
  pass
 def OnSelect(self,*args):
  """
  OnSelect(self: MenuItem,e: EventArgs)

   Raises the System.Windows.Forms.MenuItem.Select event.

  

   e: An System.EventArgs that contains the event data.
  """
  pass
 def PerformClick(self):
  """
  PerformClick(self: MenuItem)

   Generates a System.Windows.Forms.Control.Click event for the System.Windows.Forms.MenuItem,

    simulating a click by a user.
  """
  pass
 def PerformSelect(self):
  """
  PerformSelect(self: MenuItem)

   Raises the System.Windows.Forms.MenuItem.Select event for this menu item.
  """
  pass
 def ProcessCmdKey(self,*args):
  """
  ProcessCmdKey(self: Menu,msg: Message,keyData: Keys) -> (bool,Message)

  

   Processes a command key.

  

   msg: A System.Windows.Forms.Message,passed by reference that represents the window message to 

    process.

  

   keyData: One of the System.Windows.Forms.Keys values that represents the key to process.

   Returns: true if the character was processed by the control; otherwise,false.
  """
  pass
 def ToString(self):
  """
  ToString(self: MenuItem) -> str

  

   Returns a string that represents the System.Windows.Forms.MenuItem.

   Returns: A string that represents the current System.Windows.Forms.MenuItem. The string includes the type 

    and the System.Windows.Forms.MenuItem.Text property of the control.
  """
  pass
 def __enter__(self,*args):
  """
  __enter__(self: IDisposable) -> object

  

   Provides the implementation of __enter__ for objects which implement IDisposable.
  """
  pass
 def __exit__(self,*args):
  """
  __exit__(self: IDisposable,exc_type: object,exc_value: object,exc_back: object)

   Provides the implementation of __exit__ for objects which implement IDisposable.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,*__args):
  """
  __new__(cls: type)

  __new__(cls: type,text: str)

  __new__(cls: type,text: str,onClick: EventHandler)

  __new__(cls: type,text: str,onClick: EventHandler,shortcut: Shortcut)

  __new__(cls: type,text: str,items: Array[MenuItem])

  __new__(cls: type,mergeType: MenuMerge,mergeOrder: int,shortcut: Shortcut,text: str,onClick: EventHandler,onPopup: EventHandler,onSelect: EventHandler,items: Array[MenuItem])
  """
  pass
 def __str__(self,*args):
  pass
 BarBreak=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether the System.Windows.Forms.MenuItem is placed on a new line (for a menu item added to a System.Windows.Forms.MainMenu object) or in a new column (for a submenu item or menu item displayed in a System.Windows.Forms.ContextMenu).



Get: BarBreak(self: MenuItem) -> bool



Set: BarBreak(self: MenuItem)=value

"""

 Break=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether the item is placed on a new line (for a menu item added to a System.Windows.Forms.MainMenu object) or in a new column (for a menu item or submenu item displayed in a System.Windows.Forms.ContextMenu).



Get: Break(self: MenuItem) -> bool



Set: Break(self: MenuItem)=value

"""

 CanRaiseEvents=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether the component can raise an event.



"""

 Checked=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether a check mark appears next to the text of the menu item.



Get: Checked(self: MenuItem) -> bool



Set: Checked(self: MenuItem)=value

"""

 DefaultItem=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether the menu item is the default menu item.



Get: DefaultItem(self: MenuItem) -> bool



Set: DefaultItem(self: MenuItem)=value

"""

 DesignMode=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value that indicates whether the System.ComponentModel.Component is currently in design mode.



"""

 Enabled=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether the menu item is enabled.



Get: Enabled(self: MenuItem) -> bool



Set: Enabled(self: MenuItem)=value

"""

 Events=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the list of event handlers that are attached to this System.ComponentModel.Component.



"""

 Index=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating the position of the menu item in its parent menu.



Get: Index(self: MenuItem) -> int



Set: Index(self: MenuItem)=value

"""

 IsParent=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether the menu item contains child menu items.



Get: IsParent(self: MenuItem) -> bool



"""

 MdiList=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether the menu item will be populated with a list of the Multiple Document Interface (MDI) child windows that are displayed within the associated form.



Get: MdiList(self: MenuItem) -> bool



Set: MdiList(self: MenuItem)=value

"""

 MenuID=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating the Windows identifier for this menu item.



"""

 MergeOrder=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating the relative position of the menu item when it is merged with another.



Get: MergeOrder(self: MenuItem) -> int



Set: MergeOrder(self: MenuItem)=value

"""

 MergeType=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating the behavior of this menu item when its menu is merged with another.



Get: MergeType(self: MenuItem) -> MenuMerge



Set: MergeType(self: MenuItem)=value

"""

 Mnemonic=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating the mnemonic character that is associated with this menu item.



Get: Mnemonic(self: MenuItem) -> Char



"""

 OwnerDraw=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether the code that you provide draws the menu item or Windows draws the menu item.



Get: OwnerDraw(self: MenuItem) -> bool



Set: OwnerDraw(self: MenuItem)=value

"""

 Parent=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating the menu that contains this menu item.



Get: Parent(self: MenuItem) -> Menu



"""

 RadioCheck=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether the System.Windows.Forms.MenuItem,if checked,displays a radio-button instead of a check mark.



Get: RadioCheck(self: MenuItem) -> bool



Set: RadioCheck(self: MenuItem)=value

"""

 Shortcut=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating the shortcut key associated with the menu item.



Get: Shortcut(self: MenuItem) -> Shortcut



Set: Shortcut(self: MenuItem)=value

"""

 ShowShortcut=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether the shortcut key that is associated with the menu item is displayed next to the menu item caption.



Get: ShowShortcut(self: MenuItem) -> bool



Set: ShowShortcut(self: MenuItem)=value

"""

 Text=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating the caption of the menu item.



Get: Text(self: MenuItem) -> str



Set: Text(self: MenuItem)=value

"""

 Visible=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether the menu item is visible.



Get: Visible(self: MenuItem) -> bool



Set: Visible(self: MenuItem)=value

"""


 Click=None
 DrawItem=None
 MeasureItem=None
 Popup=None
 Select=None




class SwitchAttribute(Attribute,_Attribute):
 """
 Identifies a switch used in an assembly,class,or member.

 

 SwitchAttribute(switchName: str,switchType: Type)
 """
 @staticmethod
 def GetAll(assembly):
  """
  GetAll(assembly: Assembly) -> Array[SwitchAttribute]

  

   Returns all switch attributes for the specified assembly.

  

   assembly: The assembly to check for switch attributes.

   Returns: An array that contains all the switch attributes for the assembly.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,switchName,switchType):
  """ __new__(cls: type,switchName: str,switchType: Type) """
  pass
 SwitchDescription=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the description of the switch.



Get: SwitchDescription(self: SwitchAttribute) -> str



Set: SwitchDescription(self: SwitchAttribute)=value

"""

 SwitchName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the display name of the switch.



Get: SwitchName(self: SwitchAttribute) -> str



Set: SwitchName(self: SwitchAttribute)=value

"""

 SwitchType=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the type of the switch.



Get: SwitchType(self: SwitchAttribute) -> Type



Set: SwitchType(self: SwitchAttribute)=value

"""





class DataGridLengthConverter(TypeConverter):
 """
 Converts instances of various types to and from instances of the System.Windows.Controls.DataGridLength class.

 

 DataGridLengthConverter()
 """
 def CanConvertFrom(self,*__args):
  """
  CanConvertFrom(self: DataGridLengthConverter,context: ITypeDescriptorContext,sourceType: Type) -> bool

  

   Determines whether an instance of the specified type can be converted to an instance of the 

    System.Windows.Controls.DataGridLength class.

  

  

   context: An object that provides a format context.

   sourceType: The type to convert from.

   Returns: true if this converter can perform the conversion; otherwise,false.
  """
  pass
 def CanConvertTo(self,*__args):
  """
  CanConvertTo(self: DataGridLengthConverter,context: ITypeDescriptorContext,destinationType: Type) -> bool

  

   Determines whether an instance of the System.Windows.Controls.DataGridLength class can be 

    converted to an instance of the specified type.

  

  

   context: An object that provides a format context.

   destinationType: The type to convert to.

   Returns: true if this converter can perform the conversion; otherwise,false.
  """
  pass
 def ConvertFrom(self,*__args):
  """
  ConvertFrom(self: DataGridLengthConverter,context: ITypeDescriptorContext,culture: CultureInfo,value: object) -> object

  

   Converts the specified object to an instance of the System.Windows.Controls.DataGridLength class.

  

   context: An object that provides a format context.

   culture: The object to use as the current culture.

   value: The value to convert.

   Returns: The converted value.
  """
  pass
 def ConvertTo(self,*__args):
  """
  ConvertTo(self: DataGridLengthConverter,context: ITypeDescriptorContext,culture: CultureInfo,value: object,destinationType: Type) -> object

  

   Converts an instance of the System.Windows.Controls.DataGridLength class to an instance of the 

    specified type.

  

  

   context: An object that provides a format context.

   culture: The object to use as the current culture.

   value: The System.Windows.Controls.DataGridLength to convert.

   destinationType: The type to convert the value to.

   Returns: The converted value.
  """
  pass



class Component(MarshalByRefObject,IComponent,IDisposable):
 """
 Provides the base implementation for the System.ComponentModel.IComponent interface and enables object sharing between applications.

 

 Component()
 """
 def Dispose(self):
  """
  Dispose(self: Component)

   Releases all resources used by the System.ComponentModel.Component.
  """
  pass
 def GetService(self,*args):
  """
  GetService(self: Component,service: Type) -> object

  

   Returns an object that represents a service provided by the System.ComponentModel.Component or 

    by its System.ComponentModel.Container.

  

  

   service: A service provided by the System.ComponentModel.Component.

   Returns: An System.Object that represents a service provided by the System.ComponentModel.Component,or 

    null if the System.ComponentModel.Component does not provide the specified service.
  """
  pass
 def MemberwiseClone(self,*args):
  """
  MemberwiseClone(self: MarshalByRefObject,cloneIdentity: bool) -> MarshalByRefObject

  

   Creates a shallow copy of the current System.MarshalByRefObject object.

  

   cloneIdentity: false to delete the current System.MarshalByRefObject object's identity,which will cause the 

    object to be assigned a new identity when it is marshaled across a remoting boundary. A value of 

    false is usually appropriate. true to copy the current System.MarshalByRefObject object's 

    identity to its clone,which will cause remoting client calls to be routed to the remote server 

    object.

  

   Returns: A shallow copy of the current System.MarshalByRefObject object.

  MemberwiseClone(self: object) -> object

  

   Creates a shallow copy of the current System.Object.

   Returns: A shallow copy of the current System.Object.
  """
  pass
 def ToString(self):
  """
  ToString(self: Component) -> str

  

   Returns a System.String containing the name of the System.ComponentModel.Component,if any. This 

    method should not be overridden.

  

   Returns: A System.String containing the name of the System.ComponentModel.Component,if any,or null if 

    the System.ComponentModel.Component is unnamed.
  """
  pass
 def __enter__(self,*args):
  """
  __enter__(self: IDisposable) -> object

  

   Provides the implementation of __enter__ for objects which implement IDisposable.
  """
  pass
 def __exit__(self,*args):
  """
  __exit__(self: IDisposable,exc_type: object,exc_value: object,exc_back: object)

   Provides the implementation of __exit__ for objects which implement IDisposable.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __str__(self,*args):
  pass
 CanRaiseEvents=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether the component can raise an event.



"""

 Container=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.ComponentModel.IContainer that contains the System.ComponentModel.Component.



Get: Container(self: Component) -> IContainer



"""

 DesignMode=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value that indicates whether the System.ComponentModel.Component is currently in design mode.



"""

 Events=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the list of event handlers that are attached to this System.ComponentModel.Component.



"""

 Site=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the System.ComponentModel.ISite of the System.ComponentModel.Component.



Get: Site(self: Component) -> ISite



Set: Site(self: Component)=value

"""


 Disposed=None




class WebException(InvalidOperationException,ISerializable,_Exception):
 """
 The exception that is thrown when an error occurs while accessing the network through a pluggable protocol.

 

 WebException()

 WebException(message: str)

 WebException(message: str,innerException: Exception)

 WebException(message: str,status: WebExceptionStatus)

 WebException(message: str,innerException: Exception,status: WebExceptionStatus,response: WebResponse)
 """
 def add_SerializeObjectState(self,*args):
  """ add_SerializeObjectState(self: Exception,value: EventHandler[SafeSerializationEventArgs]) """
  pass
 def GetObjectData(self,serializationInfo,streamingContext):
  """
  GetObjectData(self: WebException,serializationInfo: SerializationInfo,streamingContext: StreamingContext)

   Populates a System.Runtime.Serialization.SerializationInfo instance with the data needed to 

    serialize the System.Net.WebException.

  

  

   serializationInfo: The System.Runtime.Serialization.SerializationInfo to be used.

   streamingContext: The System.Runtime.Serialization.StreamingContext to be used.
  """
  pass
 def remove_SerializeObjectState(self,*args):
  """ remove_SerializeObjectState(self: Exception,value: EventHandler[SafeSerializationEventArgs]) """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,message=None,*__args):
  """
  __new__(cls: type)

  __new__(cls: type,message: str)

  __new__(cls: type,message: str,innerException: Exception)

  __new__(cls: type,message: str,status: WebExceptionStatus)

  __new__(cls: type,message: str,innerException: Exception,status: WebExceptionStatus,response: WebResponse)

  __new__(cls: type,serializationInfo: SerializationInfo,streamingContext: StreamingContext)
  """
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Response=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the response that the remote host returned.



Get: Response(self: WebException) -> WebResponse



"""

 Status=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the status of the response.



Get: Status(self: WebException) -> WebExceptionStatus



"""





class BooleanSwitch(Switch):
 """
 Provides a simple on/off switch that controls debugging and tracing output.

 

 BooleanSwitch(displayName: str,description: str)

 BooleanSwitch(displayName: str,description: str,defaultSwitchValue: str)
 """
 @staticmethod
 def __new__(self,displayName,description,defaultSwitchValue=None):
  """
  __new__(cls: type,displayName: str,description: str)

  __new__(cls: type,displayName: str,description: str,defaultSwitchValue: str)
  """
  pass
 Enabled=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether the switch is enabled or disabled.



Get: Enabled(self: BooleanSwitch) -> bool



Set: Enabled(self: BooleanSwitch)=value

"""

 SwitchSetting=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the current setting for this switch.



"""

 Value=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the value of the switch.



"""





class AsyncOperationManager(object):
 """ Provides concurrency management for classes that support asynchronous method calls. This class cannot be inherited. """
 @staticmethod
 def CreateOperation(userSuppliedState):
  """
  CreateOperation(userSuppliedState: object) -> AsyncOperation

  

   Returns an System.ComponentModel.AsyncOperation for tracking the duration of a particular 

    asynchronous operation.

  

  

   userSuppliedState: An object used to associate a piece of client state,such as a task ID,with a particular 

    asynchronous operation.

  

   Returns: An System.ComponentModel.AsyncOperation that you can use to track the duration of an 

    asynchronous method invocation.
  """
  pass
 SynchronizationContext=None
 __all__=[
  'CreateOperation',
 ]




class BindingCompleteEventArgs(CancelEventArgs):
 """
 Provides data for the System.Windows.Forms.Binding.BindingComplete event.

 

 BindingCompleteEventArgs(binding: Binding,state: BindingCompleteState,context: BindingCompleteContext,errorText: str,exception: Exception,cancel: bool)

 BindingCompleteEventArgs(binding: Binding,state: BindingCompleteState,context: BindingCompleteContext,errorText: str,exception: Exception)

 BindingCompleteEventArgs(binding: Binding,state: BindingCompleteState,context: BindingCompleteContext,errorText: str)

 BindingCompleteEventArgs(binding: Binding,state: BindingCompleteState,context: BindingCompleteContext)
 """
 @staticmethod
 def __new__(self,binding,state,context,errorText=None,exception=None,cancel=None):
  """
  __new__(cls: type,binding: Binding,state: BindingCompleteState,context: BindingCompleteContext,errorText: str,exception: Exception,cancel: bool)

  __new__(cls: type,binding: Binding,state: BindingCompleteState,context: BindingCompleteContext,errorText: str,exception: Exception)

  __new__(cls: type,binding: Binding,state: BindingCompleteState,context: BindingCompleteContext,errorText: str)

  __new__(cls: type,binding: Binding,state: BindingCompleteState,context: BindingCompleteContext)
  """
  pass
 Binding=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the binding associated with this occurrence of a System.Windows.Forms.Binding.BindingComplete event.



Get: Binding(self: BindingCompleteEventArgs) -> Binding



"""

 BindingCompleteContext=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the direction of the binding operation.



Get: BindingCompleteContext(self: BindingCompleteEventArgs) -> BindingCompleteContext



"""

 BindingCompleteState=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the completion state of the binding operation.



Get: BindingCompleteState(self: BindingCompleteEventArgs) -> BindingCompleteState



"""

 ErrorText=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the text description of the error that occurred during the binding operation.



Get: ErrorText(self: BindingCompleteEventArgs) -> str



"""

 Exception=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the exception that occurred during the binding operation.



Get: Exception(self: BindingCompleteEventArgs) -> Exception



"""





class Array(object,ICloneable,IList,ICollection,IEnumerable,IStructuralComparable,IStructuralEquatable):
 """ Provides methods for creating,manipulating,searching,and sorting arrays,thereby serving as the base class for all arrays in the common language runtime. """
 @staticmethod
 def AsReadOnly(array):
  """ AsReadOnly[T](array: Array[T]) -> ReadOnlyCollection[T] """
  pass
 @staticmethod
 def BinarySearch(array,*__args):
  """
  BinarySearch[T](array: Array[T],value: T,comparer: IComparer[T]) -> int

  BinarySearch[T](array: Array[T],value: T) -> int

  BinarySearch[T](array: Array[T],index: int,length: int,value: T,comparer: IComparer[T]) -> int

  BinarySearch[T](array: Array[T],index: int,length: int,value: T) -> int

  BinarySearch(array: Array,index: int,length: int,value: object) -> int

  

   Searches a range of elements in a one-dimensional sorted System.Array for a value,using the 

    System.IComparable interface implemented by each element of the System.Array and by the 

    specified value.

  

  

   array: The sorted one-dimensional System.Array to search.

   index: The starting index of the range to search.

   length: The length of the range to search.

   value: The object to search for.

   Returns: The index of the specified value in the specified array,if value is found. If value is not 

    found and value is less than one or more elements in array,a negative number which is the 

    bitwise complement of the index of the first element that is larger than value. If value is not 

    found and value is greater than any of the elements in array,a negative number which is the 

    bitwise complement of (the index of the last element plus 1).

  

  BinarySearch(array: Array,value: object) -> int

  

   Searches an entire one-dimensional sorted System.Array for a specific element,using the 

    System.IComparable interface implemented by each element of the System.Array and by the 

    specified object.

  

  

   array: The sorted one-dimensional System.Array to search.

   value: The object to search for.

   Returns: The index of the specified value in the specified array,if value is found. If value is not 

    found and value is less than one or more elements in array,a negative number which is the 

    bitwise complement of the index of the first element that is larger than value. If value is not 

    found and value is greater than any of the elements in array,a negative number which is the 

    bitwise complement of (the index of the last element plus 1).

  

  BinarySearch(array: Array,index: int,length: int,value: object,comparer: IComparer) -> int

  

   Searches a range of elements in a one-dimensional sorted System.Array for a value,using the 

    specified System.Collections.IComparer interface.

  

  

   array: The sorted one-dimensional System.Array to search.

   index: The starting index of the range to search.

   length: The length of the range to search.

   value: The object to search for.

   comparer: The System.Collections.IComparer implementation to use when comparing elements.-or- null to use 

    the System.IComparable implementation of each element.

  

   Returns: The index of the specified value in the specified array,if value is found. If value is not 

    found and value is less than one or more elements in array,a negative number which is the 

    bitwise complement of the index of the first element that is larger than value. If value is not 

    found and value is greater than any of the elements in array,a negative number which is the 

    bitwise complement of (the index of the last element plus 1).

  

  BinarySearch(array: Array,value: object,comparer: IComparer) -> int

  

   Searches an entire one-dimensional sorted System.Array for a value using the specified 

    System.Collections.IComparer interface.

  

  

   array: The sorted one-dimensional System.Array to search.

   value: The object to search for.

   comparer: The System.Collections.IComparer implementation to use when comparing elements.-or- null to use 

    the System.IComparable implementation of each element.

  

   Returns: The index of the specified value in the specified array,if value is found. If value is not 

    found and value is less than one or more elements in array,a negative number which is the 

    bitwise complement of the index of the first element that is larger than value. If value is not 

    found and value is greater than any of the elements in array,a negative number which is the 

    bitwise complement of (the index of the last element plus 1).
  """
  pass
 @staticmethod
 def Clear(array,index,length):
  """
  Clear(array: Array,index: int,length: int)

   Sets a range of elements in the System.Array to zero,to false,or to null,depending on the 

    element type.

  

  

   array: The System.Array whose elements need to be cleared.

   index: The starting index of the range of elements to clear.

   length: The number of elements to clear.
  """
  pass
 def Clone(self):
  """
  Clone(self: Array) -> object

  

   Creates a shallow copy of the System.Array.

   Returns: A shallow copy of the System.Array.
  """
  pass
 @staticmethod
 def ConstrainedCopy(sourceArray,sourceIndex,destinationArray,destinationIndex,length):
  """
  ConstrainedCopy(sourceArray: Array,sourceIndex: int,destinationArray: Array,destinationIndex: int,length: int)

   Copies a range of elements from an System.Array starting at the specified source index and 

    pastes them to another System.Array starting at the specified destination index.  Guarantees 

    that all changes are undone if the copy does not succeed completely.

  

  

   sourceArray: The System.Array that contains the data to copy.

   sourceIndex: A 32-bit integer that represents the index in the sourceArray at which copying begins.

   destinationArray: The System.Array that receives the data.

   destinationIndex: A 32-bit integer that represents the index in the destinationArray at which storing begins.

   length: A 32-bit integer that represents the number of elements to copy.
  """
  pass
 @staticmethod
 def ConvertAll(array,converter):
  """ ConvertAll[(TInput,TOutput)](array: Array[TInput],converter: Converter[TInput,TOutput]) -> Array[TOutput] """
  pass
 @staticmethod
 def Copy(sourceArray,*__args):
  """
  Copy(sourceArray: Array,destinationArray: Array,length: Int64)

   Copies a range of elements from an System.Array starting at the first element and pastes them 

    into another System.Array starting at the first element. The length is specified as a 64-bit 

    integer.

  

  

   sourceArray: The System.Array that contains the data to copy.

   destinationArray: The System.Array that receives the data.

   length: A 64-bit integer that represents the number of elements to copy. The integer must be between 

    zero and System.Int32.MaxValue,inclusive.

  

  Copy(sourceArray: Array,sourceIndex: Int64,destinationArray: Array,destinationIndex: Int64,length: Int64)

   Copies a range of elements from an System.Array starting at the specified source index and 

    pastes them to another System.Array starting at the specified destination index. The length and 

    the indexes are specified as 64-bit integers.

  

  

   sourceArray: The System.Array that contains the data to copy.

   sourceIndex: A 64-bit integer that represents the index in the sourceArray at which copying begins.

   destinationArray: The System.Array that receives the data.

   destinationIndex: A 64-bit integer that represents the index in the destinationArray at which storing begins.

   length: A 64-bit integer that represents the number of elements to copy. The integer must be between 

    zero and System.Int32.MaxValue,inclusive.

  

  Copy(sourceArray: Array,destinationArray: Array,length: int)

   Copies a range of elements from an System.Array starting at the first element and pastes them 

    into another System.Array starting at the first element. The length is specified as a 32-bit 

    integer.

  

  

   sourceArray: The System.Array that contains the data to copy.

   destinationArray: The System.Array that receives the data.

   length: A 32-bit integer that represents the number of elements to copy.

  Copy(sourceArray: Array,sourceIndex: int,destinationArray: Array,destinationIndex: int,length: int)

   Copies a range of elements from an System.Array starting at the specified source index and 

    pastes them to another System.Array starting at the specified destination index. The length and 

    the indexes are specified as 32-bit integers.

  

  

   sourceArray: The System.Array that contains the data to copy.

   sourceIndex: A 32-bit integer that represents the index in the sourceArray at which copying begins.

   destinationArray: The System.Array that receives the data.

   destinationIndex: A 32-bit integer that represents the index in the destinationArray at which storing begins.

   length: A 32-bit integer that represents the number of elements to copy.
  """
  pass
 def CopyTo(self,array,index):
  """
  CopyTo(self: Array,array: Array,index: Int64)

   Copies all the elements of the current one-dimensional System.Array to the specified 

    one-dimensional System.Array starting at the specified destination System.Array index. The index 

    is specified as a 64-bit integer.

  

  

   array: The one-dimensional System.Array that is the destination of the elements copied from the current 

    System.Array.

  

   index: A 64-bit integer that represents the index in array at which copying begins.

  CopyTo(self: Array,array: Array,index: int)

   Copies all the elements of the current one-dimensional System.Array to the specified 

    one-dimensional System.Array starting at the specified destination System.Array index. The index 

    is specified as a 32-bit integer.

  

  

   array: The one-dimensional System.Array that is the destination of the elements copied from the current 

    System.Array.

  

   index: A 32-bit integer that represents the index in array at which copying begins.
  """
  pass
 @staticmethod
 def CreateInstance(elementType,*__args):
  """
  CreateInstance(elementType: Type,*lengths: Array[int]) -> Array

  

   Creates a multidimensional System.Array of the specified System.Type and dimension lengths,with 

    zero-based indexing. The dimension lengths are specified in an array of 32-bit integers.

  

  

   elementType: The System.Type of the System.Array to create.

   lengths: An array of 32-bit integers that represent the size of each dimension of the System.Array to 

    create.

  

   Returns: A new multidimensional System.Array of the specified System.Type with the specified length for 

    each dimension,using zero-based indexing.

  

  CreateInstance(elementType: Type,*lengths: Array[Int64]) -> Array

  

   Creates a multidimensional System.Array of the specified System.Type and dimension lengths,with 

    zero-based indexing. The dimension lengths are specified in an array of 64-bit integers.

  

  

   elementType: The System.Type of the System.Array to create.

   lengths: An array of 64-bit integers that represent the size of each dimension of the System.Array to 

    create. Each integer in the array must be between zero and System.Int32.MaxValue,inclusive.

  

   Returns: A new multidimensional System.Array of the specified System.Type with the specified length for 

    each dimension,using zero-based indexing.

  

  CreateInstance(elementType: Type,lengths: Array[int],lowerBounds: Array[int]) -> Array

  

   Creates a multidimensional System.Array of the specified System.Type and dimension lengths,with 

    the specified lower bounds.

  

  

   elementType: The System.Type of the System.Array to create.

   lengths: A one-dimensional array that contains the size of each dimension of the System.Array to create.

   lowerBounds: A one-dimensional array that contains the lower bound (starting index) of each dimension of the 

    System.Array to create.

  

   Returns: A new multidimensional System.Array of the specified System.Type with the specified length and 

    lower bound for each dimension.

  

  CreateInstance(elementType: Type,length: int) -> Array

  

   Creates a one-dimensional System.Array of the specified System.Type and length,with zero-based 

    indexing.

  

  

   elementType: The System.Type of the System.Array to create.

   length: The size of the System.Array to create.

   Returns: A new one-dimensional System.Array of the specified System.Type with the specified length,using 

    zero-based indexing.

  

  CreateInstance(elementType: Type,length1: int,length2: int) -> Array

  

   Creates a two-dimensional System.Array of the specified System.Type and dimension lengths,with 

    zero-based indexing.

  

  

   elementType: The System.Type of the System.Array to create.

   length1: The size of the first dimension of the System.Array to create.

   length2: The size of the second dimension of the System.Array to create.

   Returns: A new two-dimensional System.Array of the specified System.Type with the specified length for 

    each dimension,using zero-based indexing.

  

  CreateInstance(elementType: Type,length1: int,length2: int,length3: int) -> Array

  

   Creates a three-dimensional System.Array of the specified System.Type and dimension lengths,

    with zero-based indexing.

  

  

   elementType: The System.Type of the System.Array to create.

   length1: The size of the first dimension of the System.Array to create.

   length2: The size of the second dimension of the System.Array to create.

   length3: The size of the third dimension of the System.Array to create.

   Returns: A new three-dimensional System.Array of the specified System.Type with the specified length for 

    each dimension,using zero-based indexing.
  """
  pass
 @staticmethod
 def Empty():
  """ Empty[T]() -> Array[T] """
  pass
 @staticmethod
 def Exists(array,match):
  """ Exists[T](array: Array[T],match: Predicate[T]) -> bool """
  pass
 @staticmethod
 def Find(array,match):
  """ Find[T](array: Array[T],match: Predicate[T]) -> T """
  pass
 @staticmethod
 def FindAll(array,match):
  """ FindAll[T](array: Array[T],match: Predicate[T]) -> Array[T] """
  pass
 @staticmethod
 def FindIndex(array,*__args):
  """
  FindIndex[T](array: Array[T],startIndex: int,count: int,match: Predicate[T]) -> int

  FindIndex[T](array: Array[T],startIndex: int,match: Predicate[T]) -> int

  FindIndex[T](array: Array[T],match: Predicate[T]) -> int
  """
  pass
 @staticmethod
 def FindLast(array,match):
  """ FindLast[T](array: Array[T],match: Predicate[T]) -> T """
  pass
 @staticmethod
 def FindLastIndex(array,*__args):
  """
  FindLastIndex[T](array: Array[T],startIndex: int,count: int,match: Predicate[T]) -> int

  FindLastIndex[T](array: Array[T],startIndex: int,match: Predicate[T]) -> int

  FindLastIndex[T](array: Array[T],match: Predicate[T]) -> int
  """
  pass
 @staticmethod
 def ForEach(array,action):
  """ ForEach[T](array: Array[T],action: Action[T]) """
  pass
 def GetEnumerator(self):
  """
  GetEnumerator(self: Array) -> IEnumerator

  

   Returns an System.Collections.IEnumerator for the System.Array.

   Returns: An System.Collections.IEnumerator for the System.Array.
  """
  pass
 def GetLength(self,dimension):
  """
  GetLength(self: Array,dimension: int) -> int

  

   Gets a 32-bit integer that represents the number of elements in the specified dimension of the 

    System.Array.

  

  

   dimension: A zero-based dimension of the System.Array whose length needs to be determined.

   Returns: A 32-bit integer that represents the number of elements in the specified dimension.
  """
  pass
 def GetLongLength(self,dimension):
  """
  GetLongLength(self: Array,dimension: int) -> Int64

  

   Gets a 64-bit integer that represents the number of elements in the specified dimension of the 

    System.Array.

  

  

   dimension: A zero-based dimension of the System.Array whose length needs to be determined.

   Returns: A 64-bit integer that represents the number of elements in the specified dimension.
  """
  pass
 def GetLowerBound(self,dimension):
  """
  GetLowerBound(self: Array,dimension: int) -> int

  

   Gets the lower bound of the specified dimension in the System.Array.

  

   dimension: A zero-based dimension of the System.Array whose lower bound needs to be determined.

   Returns: The lower bound of the specified dimension in the System.Array.
  """
  pass
 def GetUpperBound(self,dimension):
  """
  GetUpperBound(self: Array,dimension: int) -> int

  

   Gets the upper bound of the specified dimension in the System.Array.

  

   dimension: A zero-based dimension of the System.Array whose upper bound needs to be determined.

   Returns: The upper bound of the specified dimension in the System.Array.
  """
  pass
 def GetValue(self,*__args):
  """
  GetValue(self: Array,index1: Int64,index2: Int64) -> object

  

   Gets the value at the specified position in the two-dimensional System.Array. The indexes are 

    specified as 64-bit integers.

  

  

   index1: A 64-bit integer that represents the first-dimension index of the System.Array element to get.

   index2: A 64-bit integer that represents the second-dimension index of the System.Array element to get.

   Returns: The value at the specified position in the two-dimensional System.Array.

  GetValue(self: Array,index: Int64) -> object

  

   Gets the value at the specified position in the one-dimensional System.Array. The index is 

    specified as a 64-bit integer.

  

  

   index: A 64-bit integer that represents the position of the System.Array element to get.

   Returns: The value at the specified position in the one-dimensional System.Array.

  GetValue(self: Array,*indices: Array[Int64]) -> object

  

   Gets the value at the specified position in the multidimensional System.Array. The indexes are 

    specified as an array of 64-bit integers.

  

  

   indices: A one-dimensional array of 64-bit integers that represent the indexes specifying the position of 

    the System.Array element to get.

  

   Returns: The value at the specified position in the multidimensional System.Array.

  GetValue(self: Array,index1: Int64,index2: Int64,index3: Int64) -> object

  

   Gets the value at the specified position in the three-dimensional System.Array. The indexes are 

    specified as 64-bit integers.

  

  

   index1: A 64-bit integer that represents the first-dimension index of the System.Array element to get.

   index2: A 64-bit integer that represents the second-dimension index of the System.Array element to get.

   index3: A 64-bit integer that represents the third-dimension index of the System.Array element to get.

   Returns: The value at the specified position in the three-dimensional System.Array.

  GetValue(self: Array,index: int) -> object

  

   Gets the value at the specified position in the one-dimensional System.Array. The index is 

    specified as a 32-bit integer.

  

  

   index: A 32-bit integer that represents the position of the System.Array element to get.

   Returns: The value at the specified position in the one-dimensional System.Array.

  GetValue(self: Array,*indices: Array[int]) -> object

  

   Gets the value at the specified position in the multidimensional System.Array. The indexes are 

    specified as an array of 32-bit integers.

  

  

   indices: A one-dimensional array of 32-bit integers that represent the indexes specifying the position of 

    the System.Array element to get.

  

   Returns: The value at the specified position in the multidimensional System.Array.

  GetValue(self: Array,index1: int,index2: int,index3: int) -> object

  

   Gets the value at the specified position in the three-dimensional System.Array. The indexes are 

    specified as 32-bit integers.

  

  

   index1: A 32-bit integer that represents the first-dimension index of the System.Array element to get.

   index2: A 32-bit integer that represents the second-dimension index of the System.Array element to get.

   index3: A 32-bit integer that represents the third-dimension index of the System.Array element to get.

   Returns: The value at the specified position in the three-dimensional System.Array.

  GetValue(self: Array,index1: int,index2: int) -> object

  

   Gets the value at the specified position in the two-dimensional System.Array. The indexes are 

    specified as 32-bit integers.

  

  

   index1: A 32-bit integer that represents the first-dimension index of the System.Array element to get.

   index2: A 32-bit integer that represents the second-dimension index of the System.Array element to get.

   Returns: The value at the specified position in the two-dimensional System.Array.
  """
  pass
 @staticmethod
 def IndexOf(array,value,startIndex=None,count=None):
  """
  IndexOf[T](array: Array[T],value: T) -> int

  IndexOf[T](array: Array[T],value: T,startIndex: int) -> int

  IndexOf[T](array: Array[T],value: T,startIndex: int,count: int) -> int

  IndexOf(array: Array,value: object) -> int

  

   Searches for the specified object and returns the index of the first occurrence within the 

    entire one-dimensional System.Array.

  

  

   array: The one-dimensional System.Array to search.

   value: The object to locate in array.

   Returns: The index of the first occurrence of value within the entire array,if found; otherwise,the 

    lower bound of the array minus 1.

  

  IndexOf(array: Array,value: object,startIndex: int) -> int

  

   Searches for the specified object and returns the index of the first occurrence within the range 

    of elements in the one-dimensional System.Array that extends from the specified index to the 

    last element.

  

  

   array: The one-dimensional System.Array to search.

   value: The object to locate in array.

   startIndex: The starting index of the search. 0 (zero) is valid in an empty array.

   Returns: The index of the first occurrence of value within the range of elements in array that extends 

    from startIndex to the last element,if found; otherwise,the lower bound of the array minus 1.

  

  IndexOf(array: Array,value: object,startIndex: int,count: int) -> int

  

   Searches for the specified object and returns the index of the first occurrence within the range 

    of elements in the one-dimensional System.Array that starts at the specified index and contains 

    the specified number of elements.

  

  

   array: The one-dimensional System.Array to search.

   value: The object to locate in array.

   startIndex: The starting index of the search. 0 (zero) is valid in an empty array.

   count: The number of elements in the section to search.

   Returns: The index of the first occurrence of value within the range of elements in array that starts at 

    startIndex and contains the number of elements specified in count,if found; otherwise,the 

    lower bound of the array minus 1.
  """
  pass
 def Initialize(self):
  """
  Initialize(self: Array)

   Initializes every element of the value-type System.Array by calling the default constructor of 

    the value type.
  """
  pass
 @staticmethod
 def LastIndexOf(array,value,startIndex=None,count=None):
  """
  LastIndexOf[T](array: Array[T],value: T) -> int

  LastIndexOf[T](array: Array[T],value: T,startIndex: int) -> int

  LastIndexOf[T](array: Array[T],value: T,startIndex: int,count: int) -> int

  LastIndexOf(array: Array,value: object) -> int

  

   Searches for the specified object and returns the index of the last occurrence within the entire 

    one-dimensional System.Array.

  

  

   array: The one-dimensional System.Array to search.

   value: The object to locate in array.

   Returns: The index of the last occurrence of value within the entire array,if found; otherwise,the 

    lower bound of the array minus 1.

  

  LastIndexOf(array: Array,value: object,startIndex: int) -> int

  

   Searches for the specified object and returns the index of the last occurrence within the range 

    of elements in the one-dimensional System.Array that extends from the first element to the 

    specified index.

  

  

   array: The one-dimensional System.Array to search.

   value: The object to locate in array.

   startIndex: The starting index of the backward search.

   Returns: The index of the last occurrence of value within the range of elements in array that extends 

    from the first element to startIndex,if found; otherwise,the lower bound of the array minus 1.

  

  LastIndexOf(array: Array,value: object,startIndex: int,count: int) -> int

  

   Searches for the specified object and returns the index of the last occurrence within the range 

    of elements in the one-dimensional System.Array that contains the specified number of elements 

    and ends at the specified index.

  

  

   array: The one-dimensional System.Array to search.

   value: The object to locate in array.

   startIndex: The starting index of the backward search.

   count: The number of elements in the section to search.

   Returns: The index of the last occurrence of value within the range of elements in array that contains 

    the number of elements specified in count and ends at startIndex,if found; otherwise,the lower 

    bound of the array minus 1.
  """
  pass
 @staticmethod
 def Resize(array,newSize):
  """ Resize[T](array: Array[T],newSize: int) -> Array[T] """
  pass
 @staticmethod
 def Reverse(array,index=None,length=None):
  """
  Reverse(array: Array,index: int,length: int)

   Reverses the sequence of the elements in a range of elements in the one-dimensional System.Array.

  

   array: The one-dimensional System.Array to reverse.

   index: The starting index of the section to reverse.

   length: The number of elements in the section to reverse.

  Reverse(array: Array)

   Reverses the sequence of the elements in the entire one-dimensional System.Array.

  

   array: The one-dimensional System.Array to reverse.
  """
  pass
 def SetValue(self,value,*__args):
  """
  SetValue(self: Array,value: object,index1: Int64,index2: Int64)

   Sets a value to the element at the specified position in the two-dimensional System.Array. The 

    indexes are specified as 64-bit integers.

  

  

   value: The new value for the specified element.

   index1: A 64-bit integer that represents the first-dimension index of the System.Array element to set.

   index2: A 64-bit integer that represents the second-dimension index of the System.Array element to set.

  SetValue(self: Array,value: object,index: Int64)

   Sets a value to the element at the specified position in the one-dimensional System.Array. The 

    index is specified as a 64-bit integer.

  

  

   value: The new value for the specified element.

   index: A 64-bit integer that represents the position of the System.Array element to set.

  SetValue(self: Array,value: object,*indices: Array[Int64])

   Sets a value to the element at the specified position in the multidimensional System.Array. The 

    indexes are specified as an array of 64-bit integers.

  

  

   value: The new value for the specified element.

   indices: A one-dimensional array of 64-bit integers that represent the indexes specifying the position of 

    the element to set.

  

  SetValue(self: Array,value: object,index1: Int64,index2: Int64,index3: Int64)

   Sets a value to the element at the specified position in the three-dimensional System.Array. The 

    indexes are specified as 64-bit integers.

  

  

   value: The new value for the specified element.

   index1: A 64-bit integer that represents the first-dimension index of the System.Array element to set.

   index2: A 64-bit integer that represents the second-dimension index of the System.Array element to set.

   index3: A 64-bit integer that represents the third-dimension index of the System.Array element to set.

  SetValue(self: Array,value: object,index1: int,index2: int)

   Sets a value to the element at the specified position in the two-dimensional System.Array. The 

    indexes are specified as 32-bit integers.

  

  

   value: The new value for the specified element.

   index1: A 32-bit integer that represents the first-dimension index of the System.Array element to set.

   index2: A 32-bit integer that represents the second-dimension index of the System.Array element to set.

  SetValue(self: Array,value: object,index: int)

   Sets a value to the element at the specified position in the one-dimensional System.Array. The 

    index is specified as a 32-bit integer.

  

  

   value: The new value for the specified element.

   index: A 32-bit integer that represents the position of the System.Array element to set.

  SetValue(self: Array,value: object,*indices: Array[int])

   Sets a value to the element at the specified position in the multidimensional System.Array. The 

    indexes are specified as an array of 32-bit integers.

  

  

   value: The new value for the specified element.

   indices: A one-dimensional array of 32-bit integers that represent the indexes specifying the position of 

    the element to set.

  

  SetValue(self: Array,value: object,index1: int,index2: int,index3: int)

   Sets a value to the element at the specified position in the three-dimensional System.Array. The 

    indexes are specified as 32-bit integers.

  

  

   value: The new value for the specified element.

   index1: A 32-bit integer that represents the first-dimension index of the System.Array element to set.

   index2: A 32-bit integer that represents the second-dimension index of the System.Array element to set.

   index3: A 32-bit integer that represents the third-dimension index of the System.Array element to set.
  """
  pass
 @staticmethod
 def Sort(*__args):
  """
  Sort[(TKey,TValue)](keys: Array[TKey],items: Array[TValue],index: int,length: int)Sort[T](array: Array[T],comparer: IComparer[T])Sort[(TKey,TValue)](keys: Array[TKey],items: Array[TValue])Sort[T](array: Array[T],index: int,length: int)Sort[(TKey,TValue)](keys: Array[TKey],items: Array[TValue],index: int,length: int,comparer: IComparer[TKey])Sort[T](array: Array[T],comparison: Comparison[T])Sort[(TKey,TValue)](keys: Array[TKey],items: Array[TValue],comparer: IComparer[TKey])Sort[T](array: Array[T],index: int,length: int,comparer: IComparer[T])Sort[T](array: Array[T])Sort(array: Array,index: int,length: int)

   Sorts the elements in a range of elements in a one-dimensional System.Array using the 

    System.IComparable implementation of each element of the System.Array.

  

  

   array: The one-dimensional System.Array to sort.

   index: The starting index of the range to sort.

   length: The number of elements in the range to sort.

  Sort(keys: Array,items: Array,index: int,length: int)

   Sorts a range of elements in a pair of one-dimensional System.Array objects (one contains the 

    keys and the other contains the corresponding items) based on the keys in the first System.Array 

    using the System.IComparable implementation of each key.

  

  

   keys: The one-dimensional System.Array that contains the keys to sort.

   items: The one-dimensional System.Array that contains the items that correspond to each of the keys in 

    the keysSystem.Array.-or-null to sort only the keysSystem.Array.

  

   index: The starting index of the range to sort.

   length: The number of elements in the range to sort.

  Sort(array: Array)

   Sorts the elements in an entire one-dimensional System.Array using the System.IComparable 

    implementation of each element of the System.Array.

  

  

   array: The one-dimensional System.Array to sort.

  Sort(keys: Array,items: Array)

   Sorts a pair of one-dimensional System.Array objects (one contains the keys and the other 

    contains the corresponding items) based on the keys in the first System.Array using the 

    System.IComparable implementation of each key.

  

  

   keys: The one-dimensional System.Array that contains the keys to sort.

   items: The one-dimensional System.Array that contains the items that correspond to each of the keys in 

    the keysSystem.Array.-or-null to sort only the keysSystem.Array.

  

  Sort(array: Array,index: int,length: int,comparer: IComparer)

   Sorts the elements in a range of elements in a one-dimensional System.Array using the specified 

    System.Collections.IComparer.

  

  

   array: The one-dimensional System.Array to sort.

   index: The starting index of the range to sort.

   length: The number of elements in the range to sort.

   comparer: The System.Collections.IComparer implementation to use when comparing elements.-or-null to use 

    the System.IComparable implementation of each element.

  

  Sort(keys: Array,items: Array,index: int,length: int,comparer: IComparer)

   Sorts a range of elements in a pair of one-dimensional System.Array objects (one contains the 

    keys and the other contains the corresponding items) based on the keys in the first System.Array 

    using the specified System.Collections.IComparer.

  

  

   keys: The one-dimensional System.Array that contains the keys to sort.

   items: The one-dimensional System.Array that contains the items that correspond to each of the keys in 

    the keysSystem.Array.-or-null to sort only the keysSystem.Array.

  

   index: The starting index of the range to sort.

   length: The number of elements in the range to sort.

   comparer: The System.Collections.IComparer implementation to use when comparing elements.-or-null to use 

    the System.IComparable implementation of each element.

  

  Sort(array: Array,comparer: IComparer)

   Sorts the elements in a one-dimensional System.Array using the specified 

    System.Collections.IComparer.

  

  

   array: The one-dimensional System.Array to sort.

   comparer: The System.Collections.IComparer implementation to use when comparing elements.-or-null to use 

    the System.IComparable implementation of each element.

  

  Sort(keys: Array,items: Array,comparer: IComparer)

   Sorts a pair of one-dimensional System.Array objects (one contains the keys and the other 

    contains the corresponding items) based on the keys in the first System.Array using the 

    specified System.Collections.IComparer.

  

  

   keys: The one-dimensional System.Array that contains the keys to sort.

   items: The one-dimensional System.Array that contains the items that correspond to each of the keys in 

    the keysSystem.Array.-or-null to sort only the keysSystem.Array.

  

   comparer: The System.Collections.IComparer implementation to use when comparing elements.-or-null to use 

    the System.IComparable implementation of each element.
  """
  pass
 @staticmethod
 def TrueForAll(array,match):
  """ TrueForAll[T](array: Array[T],match: Predicate[T]) -> bool """
  pass
 def __add__(self,*args):
  """ x.__add__(y) <==> x+y """
  pass
 def __contains__(self,*args):
  """
  __contains__(self: IList,value: object) -> bool

  

   Determines whether the System.Collections.IList contains a specific value.

  

   value: The object to locate in the System.Collections.IList.

   Returns: true if the System.Object is found in the System.Collections.IList; otherwise,false.
  """
  pass
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __getitem__(self,*args):
  """ x.__getitem__(y) <==> x[y]x.__getitem__(y) <==> x[y]x.__getitem__(y) <==> x[y]x.__getitem__(y) <==> x[y] """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __hash__(self,*args):
  """ x.__hash__() <==> hash(x) """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __iter__(self,*args):
  """ __iter__(self: IEnumerable) -> object """
  pass
 def __len__(self,*args):
  """ x.__len__() <==> len(x) """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __mul__(self,*args):
  """ x.__mul__(y) <==> x*y """
  pass
 @staticmethod
 def __new__(self,*args): #cannot find CLR constructor
  """
  __new__(pythonType: type,items: object) -> object

  __new__(pythonType: type,items: ICollection) -> object
  """
  pass
 def __ne__(self,*args):
  pass
 def __radd__(self,*args):
  """ __radd__(data1: Array,data2: Array) -> Array """
  pass
 def __reduce_ex__(self,*args):
  pass
 def __repr__(self,*args):
  """ __repr__(self: Array) -> str """
  pass
 def __setitem__(self,*args):
  """ x.__setitem__(i,y) <==> x[i]=x.__setitem__(i,y) <==> x[i]=x.__setitem__(i,y) <==> x[i]= """
  pass
 IsFixedSize=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether the System.Array has a fixed size.



Get: IsFixedSize(self: Array) -> bool



"""

 IsReadOnly=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether the System.Array is read-only.



Get: IsReadOnly(self: Array) -> bool



"""

 IsSynchronized=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether access to the System.Array is synchronized (thread safe).



Get: IsSynchronized(self: Array) -> bool



"""

 Length=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a 32-bit integer that represents the total number of elements in all the dimensions of the System.Array.



Get: Length(self: Array) -> int



"""

 LongLength=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a 64-bit integer that represents the total number of elements in all the dimensions of the System.Array.



Get: LongLength(self: Array) -> Int64



"""

 Rank=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the rank (number of dimensions) of the System.Array.



Get: Rank(self: Array) -> int



"""

 SyncRoot=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets an object that can be used to synchronize access to the System.Array.



Get: SyncRoot(self: Array) -> object



"""





class DataTemplateSelector(object):
 """
 Provides a way to choose a System.Windows.DataTemplate based on the data object and the data-bound element.

 

 DataTemplateSelector()
 """
 def SelectTemplate(self,item,container):
  """
  SelectTemplate(self: DataTemplateSelector,item: object,container: DependencyObject) -> DataTemplate

  

   When overridden in a derived class,returns a System.Windows.DataTemplate based on custom logic.

  

   item: The data object for which to select the template.

   container: The data-bound object.

   Returns: Returns a System.Windows.DataTemplate or null. The default value is null.
  """
  pass



class UICuesEventArgs(EventArgs):
 """
 Provides data for the System.Windows.Forms.Control.ChangeUICues event.

 

 UICuesEventArgs(uicues: UICues)
 """
 @staticmethod
 def __new__(self,uicues):
  """ __new__(cls: type,uicues: UICues) """
  pass
 Changed=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the bitwise combination of the System.Windows.Forms.UICues values.



Get: Changed(self: UICuesEventArgs) -> UICues



"""

 ChangeFocus=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether the state of the focus cues has changed.



Get: ChangeFocus(self: UICuesEventArgs) -> bool



"""

 ChangeKeyboard=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether the state of the keyboard cues has changed.



Get: ChangeKeyboard(self: UICuesEventArgs) -> bool



"""

 ShowFocus=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether focus rectangles are shown after the change.



Get: ShowFocus(self: UICuesEventArgs) -> bool



"""

 ShowKeyboard=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether keyboard cues are underlined after the change.



Get: ShowKeyboard(self: UICuesEventArgs) -> bool



"""





class HandledMouseEventArgs(MouseEventArgs):
 """
 Allows a custom control to prevent the System.Windows.Forms.Control.MouseWheel event from being sent to its parent container.

 

 HandledMouseEventArgs(button: MouseButtons,clicks: int,x: int,y: int,delta: int)

 HandledMouseEventArgs(button: MouseButtons,clicks: int,x: int,y: int,delta: int,defaultHandledValue: bool)
 """
 @staticmethod
 def __new__(self,button,clicks,x,y,delta,defaultHandledValue=None):
  """
  __new__(cls: type,button: MouseButtons,clicks: int,x: int,y: int,delta: int)

  __new__(cls: type,button: MouseButtons,clicks: int,x: int,y: int,delta: int,defaultHandledValue: bool)
  """
  pass
 Handled=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets whether this event should be forwarded to the control's parent container.



Get: Handled(self: HandledMouseEventArgs) -> bool



Set: Handled(self: HandledMouseEventArgs)=value

"""





class HttpListenerRequest(object):
 """ Describes an incoming HTTP request to an System.Net.HttpListener object. This class cannot be inherited. """
 def BeginGetClientCertificate(self,requestCallback,state):
  """
  BeginGetClientCertificate(self: HttpListenerRequest,requestCallback: AsyncCallback,state: object) -> IAsyncResult

  

   Begins an asynchronous request for the client's X.509 v.3 certificate.

  

   requestCallback: An System.AsyncCallback delegate that references the method to invoke when the operation is 

    complete.

  

   state: A user-defined object that contains information about the operation. This object is passed to 

    the callback delegate when the operation completes.

  

   Returns: An System.IAsyncResult that indicates the status of the operation.
  """
  pass
 def EndGetClientCertificate(self,asyncResult):
  """
  EndGetClientCertificate(self: HttpListenerRequest,asyncResult: IAsyncResult) -> X509Certificate2

  

   Ends an asynchronous request for the client's X.509 v.3 certificate.

  

   asyncResult: The pending request for the certificate.

   Returns: The System.IAsyncResult object that is returned when the operation started.
  """
  pass
 def GetClientCertificate(self):
  """
  GetClientCertificate(self: HttpListenerRequest) -> X509Certificate2

  

   Retrieves the client's X.509 v.3 certificate.

   Returns: A System.Security.Cryptography.X509Certificates object that contains the client's X.509 v.3 

    certificate.
  """
  pass
 def GetClientCertificateAsync(self):
  """ GetClientCertificateAsync(self: HttpListenerRequest) -> Task[X509Certificate2] """
  pass
 AcceptTypes=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the MIME types accepted by the client.



Get: AcceptTypes(self: HttpListenerRequest) -> Array[str]



"""

 ClientCertificateError=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets an error code that identifies a problem with the System.Security.Cryptography.X509Certificates.X509Certificate provided by the client.



Get: ClientCertificateError(self: HttpListenerRequest) -> int



"""

 ContentEncoding=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the content encoding that can be used with data sent with the request



Get: ContentEncoding(self: HttpListenerRequest) -> Encoding



"""

 ContentLength64=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the length of the body data included in the request.



Get: ContentLength64(self: HttpListenerRequest) -> Int64



"""

 ContentType=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the MIME type of the body data included in the request.



Get: ContentType(self: HttpListenerRequest) -> str



"""

 Cookies=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the cookies sent with the request.



Get: Cookies(self: HttpListenerRequest) -> CookieCollection



"""

 HasEntityBody=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a System.Boolean value that indicates whether the request has associated body data.



Get: HasEntityBody(self: HttpListenerRequest) -> bool



"""

 Headers=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the collection of header name/value pairs sent in the request.



Get: Headers(self: HttpListenerRequest) -> NameValueCollection



"""

 HttpMethod=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the HTTP method specified by the client.



Get: HttpMethod(self: HttpListenerRequest) -> str



"""

 InputStream=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a stream that contains the body data sent by the client.



Get: InputStream(self: HttpListenerRequest) -> Stream



"""

 IsAuthenticated=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a System.Boolean value that indicates whether the client sending this request is authenticated.



Get: IsAuthenticated(self: HttpListenerRequest) -> bool



"""

 IsLocal=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a System.Boolean value that indicates whether the request is sent from the local computer.



Get: IsLocal(self: HttpListenerRequest) -> bool



"""

 IsSecureConnection=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a System.Boolean value that indicates whether the TCP connection used to send the request is using the Secure Sockets Layer (SSL) protocol.



Get: IsSecureConnection(self: HttpListenerRequest) -> bool



"""

 IsWebSocketRequest=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: IsWebSocketRequest(self: HttpListenerRequest) -> bool



"""

 KeepAlive=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a System.Boolean value that indicates whether the client requests a persistent connection.



Get: KeepAlive(self: HttpListenerRequest) -> bool



"""

 LocalEndPoint=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get the server IP address and port number to which the request is directed.



Get: LocalEndPoint(self: HttpListenerRequest) -> IPEndPoint



"""

 ProtocolVersion=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the HTTP version used by the requesting client.



Get: ProtocolVersion(self: HttpListenerRequest) -> Version



"""

 QueryString=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the query string included in the request.



Get: QueryString(self: HttpListenerRequest) -> NameValueCollection



"""

 RawUrl=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the URL information (without the host and port) requested by the client.



Get: RawUrl(self: HttpListenerRequest) -> str



"""

 RemoteEndPoint=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the client IP address and port number from which the request originated.



Get: RemoteEndPoint(self: HttpListenerRequest) -> IPEndPoint



"""

 RequestTraceIdentifier=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the request identifier of the incoming HTTP request.



Get: RequestTraceIdentifier(self: HttpListenerRequest) -> Guid



"""

 ServiceName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the Service Provider Name (SPN) that the client sent on the request.



Get: ServiceName(self: HttpListenerRequest) -> str



"""

 TransportContext=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Net.TransportContext for the client request.



Get: TransportContext(self: HttpListenerRequest) -> TransportContext



"""

 Url=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Uri object requested by the client.



Get: Url(self: HttpListenerRequest) -> Uri



"""

 UrlReferrer=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the Uniform Resource Identifier (URI) of the resource that referred the client to the server.



Get: UrlReferrer(self: HttpListenerRequest) -> Uri



"""

 UserAgent=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the user agent presented by the client.



Get: UserAgent(self: HttpListenerRequest) -> str



"""

 UserHostAddress=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the server IP address and port number to which the request is directed.



Get: UserHostAddress(self: HttpListenerRequest) -> str



"""

 UserHostName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the DNS name and,if provided,the port number specified by the client.



Get: UserHostName(self: HttpListenerRequest) -> str



"""

 UserLanguages=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the natural languages that are preferred for the response.



Get: UserLanguages(self: HttpListenerRequest) -> Array[str]



"""





class HttpWebRequest(WebRequest,ISerializable):
 """
 Provides an HTTP-specific implementation of the System.Net.WebRequest class.

 

 HttpWebRequest()
 """
 def Abort(self):
  """
  Abort(self: HttpWebRequest)

   Cancels a request to an Internet resource.
  """
  pass
 def AddRange(self,*__args):
  """
  AddRange(self: HttpWebRequest,rangeSpecifier: str,from: Int64,to: Int64)

   Adds a range header to a request for a specified range.

  

   rangeSpecifier: The description of the range.

   from: The position at which to start sending data.

   to: The position at which to stop sending data.

  AddRange(self: HttpWebRequest,rangeSpecifier: str,from: int,to: int)

   Adds a range header to a request for a specified range.

  

   rangeSpecifier: The description of the range.

   from: The position at which to start sending data.

   to: The position at which to stop sending data.

  AddRange(self: HttpWebRequest,rangeSpecifier: str,range: Int64)

   Adds a Range header to a request for a specific range from the beginning or end of the requested 

    data.

  

  

   rangeSpecifier: The description of the range.

   range: The starting or ending point of the range.

  AddRange(self: HttpWebRequest,rangeSpecifier: str,range: int)

   Adds a Range header to a request for a specific range from the beginning or end of the requested 

    data.

  

  

   rangeSpecifier: The description of the range.

   range: The starting or ending point of the range.

  AddRange(self: HttpWebRequest,from: Int64,to: Int64)

   Adds a byte range header to the request for a specified range.

  

   from: The position at which to start sending data.

   to: The position at which to stop sending data.

  AddRange(self: HttpWebRequest,from: int,to: int)

   Adds a byte range header to the request for a specified range.

  

   from: The position at which to start sending data.

   to: The position at which to stop sending data.

  AddRange(self: HttpWebRequest,range: Int64)

   Adds a byte range header to a request for a specific range from the beginning or end of the 

    requested data.

  

  

   range: The starting or ending point of the range.

  AddRange(self: HttpWebRequest,range: int)

   Adds a byte range header to a request for a specific range from the beginning or end of the 

    requested data.

  

  

   range: The starting or ending point of the range.
  """
  pass
 def BeginGetRequestStream(self,callback,state):
  """
  BeginGetRequestStream(self: HttpWebRequest,callback: AsyncCallback,state: object) -> IAsyncResult

  

   Begins an asynchronous request for a System.IO.Stream object to use to write data.

  

   callback: The System.AsyncCallback delegate.

   state: The state object for this request.

   Returns: An System.IAsyncResult that references the asynchronous request.
  """
  pass
 def BeginGetResponse(self,callback,state):
  """
  BeginGetResponse(self: HttpWebRequest,callback: AsyncCallback,state: object) -> IAsyncResult

  

   Begins an asynchronous request to an Internet resource.

  

   callback: The System.AsyncCallback delegate

   state: The state object for this request.

   Returns: An System.IAsyncResult that references the asynchronous request for a response.
  """
  pass
 def EndGetRequestStream(self,asyncResult,context=None):
  """
  EndGetRequestStream(self: HttpWebRequest,asyncResult: IAsyncResult) -> (Stream,TransportContext)

  

   Ends an asynchronous request for a System.IO.Stream object to use to write data and outputs the 

    System.Net.TransportContext associated with the stream.

  

  

   asyncResult: The pending request for a stream.

   Returns: A System.IO.Stream to use to write request data.

  EndGetRequestStream(self: HttpWebRequest,asyncResult: IAsyncResult) -> Stream

  

   Ends an asynchronous request for a System.IO.Stream object to use to write data.

  

   asyncResult: The pending request for a stream.

   Returns: A System.IO.Stream to use to write request data.
  """
  pass
 def EndGetResponse(self,asyncResult):
  """
  EndGetResponse(self: HttpWebRequest,asyncResult: IAsyncResult) -> WebResponse

  

   Ends an asynchronous request to an Internet resource.

  

   asyncResult: The pending request for a response.

   Returns: A System.Net.WebResponse that contains the response from the Internet resource.
  """
  pass
 def GetObjectData(self,*args):
  """
  GetObjectData(self: HttpWebRequest,serializationInfo: SerializationInfo,streamingContext: StreamingContext)

   Populates a System.Runtime.Serialization.SerializationInfo with the data required to serialize 

    the target object.

  

  

   serializationInfo: The System.Runtime.Serialization.SerializationInfo to populate with data.

   streamingContext: A System.Runtime.Serialization.StreamingContext that specifies the destination for this 

    serialization.
  """
  pass
 def GetRequestStream(self,context=None):
  """
  GetRequestStream(self: HttpWebRequest) -> (Stream,TransportContext)

  

   Gets a System.IO.Stream object to use to write request data and outputs the 

    System.Net.TransportContext associated with the stream.

  

   Returns: A System.IO.Stream to use to write request data.

  GetRequestStream(self: HttpWebRequest) -> Stream

  

   Gets a System.IO.Stream object to use to write request data.

   Returns: A System.IO.Stream to use to write request data.
  """
  pass
 def GetResponse(self):
  """
  GetResponse(self: HttpWebRequest) -> WebResponse

  

   Returns a response from an Internet resource.

   Returns: A System.Net.WebResponse that contains the response from the Internet resource.
  """
  pass
 def MemberwiseClone(self,*args):
  """
  MemberwiseClone(self: MarshalByRefObject,cloneIdentity: bool) -> MarshalByRefObject

  

   Creates a shallow copy of the current System.MarshalByRefObject object.

  

   cloneIdentity: false to delete the current System.MarshalByRefObject object's identity,which will cause the 

    object to be assigned a new identity when it is marshaled across a remoting boundary. A value of 

    false is usually appropriate. true to copy the current System.MarshalByRefObject object's 

    identity to its clone,which will cause remoting client calls to be routed to the remote server 

    object.

  

   Returns: A shallow copy of the current System.MarshalByRefObject object.

  MemberwiseClone(self: object) -> object

  

   Creates a shallow copy of the current System.Object.

   Returns: A shallow copy of the current System.Object.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self):
  """
  __new__(cls: type)

  __new__(cls: type,serializationInfo: SerializationInfo,streamingContext: StreamingContext)
  """
  pass
 def __reduce_ex__(self,*args):
  pass
 Accept=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the value of the Accept HTTP header.



Get: Accept(self: HttpWebRequest) -> str



Set: Accept(self: HttpWebRequest)=value

"""

 Address=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the Uniform Resource Identifier (URI) of the Internet resource that actually responds to the request.



Get: Address(self: HttpWebRequest) -> Uri



"""

 AllowAutoRedirect=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value that indicates whether the request should follow redirection responses.



Get: AllowAutoRedirect(self: HttpWebRequest) -> bool



Set: AllowAutoRedirect(self: HttpWebRequest)=value

"""

 AllowReadStreamBuffering=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: AllowReadStreamBuffering(self: HttpWebRequest) -> bool



Set: AllowReadStreamBuffering(self: HttpWebRequest)=value

"""

 AllowWriteStreamBuffering=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value that indicates whether to buffer the data sent to the Internet resource.



Get: AllowWriteStreamBuffering(self: HttpWebRequest) -> bool



Set: AllowWriteStreamBuffering(self: HttpWebRequest)=value

"""

 AutomaticDecompression=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the type of decompression that is used.



Get: AutomaticDecompression(self: HttpWebRequest) -> DecompressionMethods



Set: AutomaticDecompression(self: HttpWebRequest)=value

"""

 ClientCertificates=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the collection of security certificates that are associated with this request.



Get: ClientCertificates(self: HttpWebRequest) -> X509CertificateCollection



Set: ClientCertificates(self: HttpWebRequest)=value

"""

 Connection=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the value of the Connection HTTP header.



Get: Connection(self: HttpWebRequest) -> str



Set: Connection(self: HttpWebRequest)=value

"""

 ConnectionGroupName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the name of the connection group for the request.



Get: ConnectionGroupName(self: HttpWebRequest) -> str



Set: ConnectionGroupName(self: HttpWebRequest)=value

"""

 ContentLength=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the Content-length HTTP header.



Get: ContentLength(self: HttpWebRequest) -> Int64



Set: ContentLength(self: HttpWebRequest)=value

"""

 ContentType=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the value of the Content-type HTTP header.



Get: ContentType(self: HttpWebRequest) -> str



Set: ContentType(self: HttpWebRequest)=value

"""

 ContinueDelegate=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the delegate method called when an HTTP 100-continue response is received from the Internet resource.



Get: ContinueDelegate(self: HttpWebRequest) -> HttpContinueDelegate



Set: ContinueDelegate(self: HttpWebRequest)=value

"""

 ContinueTimeout=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: ContinueTimeout(self: HttpWebRequest) -> int



Set: ContinueTimeout(self: HttpWebRequest)=value

"""

 CookieContainer=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the cookies associated with the request.



Get: CookieContainer(self: HttpWebRequest) -> CookieContainer



Set: CookieContainer(self: HttpWebRequest)=value

"""

 Credentials=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets authentication information for the request.



Get: Credentials(self: HttpWebRequest) -> ICredentials



Set: Credentials(self: HttpWebRequest)=value

"""

 Date=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get or set the Date HTTP header value to use in an HTTP request.



Get: Date(self: HttpWebRequest) -> DateTime



Set: Date(self: HttpWebRequest)=value

"""

 Expect=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the value of the Expect HTTP header.



Get: Expect(self: HttpWebRequest) -> str



Set: Expect(self: HttpWebRequest)=value

"""

 HaveResponse=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value that indicates whether a response has been received from an Internet resource.



Get: HaveResponse(self: HttpWebRequest) -> bool



"""

 Headers=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Specifies a collection of the name/value pairs that make up the HTTP headers.



Get: Headers(self: HttpWebRequest) -> WebHeaderCollection



Set: Headers(self: HttpWebRequest)=value

"""

 Host=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get or set the Host header value to use in an HTTP request independent from the request URI.



Get: Host(self: HttpWebRequest) -> str



Set: Host(self: HttpWebRequest)=value

"""

 IfModifiedSince=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the value of the If-Modified-Since HTTP header.



Get: IfModifiedSince(self: HttpWebRequest) -> DateTime



Set: IfModifiedSince(self: HttpWebRequest)=value

"""

 KeepAlive=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value that indicates whether to make a persistent connection to the Internet resource.



Get: KeepAlive(self: HttpWebRequest) -> bool



Set: KeepAlive(self: HttpWebRequest)=value

"""

 MaximumAutomaticRedirections=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the maximum number of redirects that the request follows.



Get: MaximumAutomaticRedirections(self: HttpWebRequest) -> int



Set: MaximumAutomaticRedirections(self: HttpWebRequest)=value

"""

 MaximumResponseHeadersLength=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the maximum allowed length of the response headers.



Get: MaximumResponseHeadersLength(self: HttpWebRequest) -> int



Set: MaximumResponseHeadersLength(self: HttpWebRequest)=value

"""

 MediaType=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the media type of the request.



Get: MediaType(self: HttpWebRequest) -> str



Set: MediaType(self: HttpWebRequest)=value

"""

 Method=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the method for the request.



Get: Method(self: HttpWebRequest) -> str



Set: Method(self: HttpWebRequest)=value

"""

 Pipelined=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value that indicates whether to pipeline the request to the Internet resource.



Get: Pipelined(self: HttpWebRequest) -> bool



Set: Pipelined(self: HttpWebRequest)=value

"""

 PreAuthenticate=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value that indicates whether to send an Authorization header with the request.



Get: PreAuthenticate(self: HttpWebRequest) -> bool



Set: PreAuthenticate(self: HttpWebRequest)=value

"""

 ProtocolVersion=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the version of HTTP to use for the request.



Get: ProtocolVersion(self: HttpWebRequest) -> Version



Set: ProtocolVersion(self: HttpWebRequest)=value

"""

 Proxy=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets proxy information for the request.



Get: Proxy(self: HttpWebRequest) -> IWebProxy



Set: Proxy(self: HttpWebRequest)=value

"""

 ReadWriteTimeout=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a time-out in milliseconds when writing to or reading from a stream.



Get: ReadWriteTimeout(self: HttpWebRequest) -> int



Set: ReadWriteTimeout(self: HttpWebRequest)=value

"""

 Referer=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the value of the Referer HTTP header.



Get: Referer(self: HttpWebRequest) -> str



Set: Referer(self: HttpWebRequest)=value

"""

 RequestUri=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the original Uniform Resource Identifier (URI) of the request.



Get: RequestUri(self: HttpWebRequest) -> Uri



"""

 SendChunked=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value that indicates whether to send data in segments to the Internet resource.



Get: SendChunked(self: HttpWebRequest) -> bool



Set: SendChunked(self: HttpWebRequest)=value

"""

 ServerCertificateValidationCallback=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: ServerCertificateValidationCallback(self: HttpWebRequest) -> RemoteCertificateValidationCallback



Set: ServerCertificateValidationCallback(self: HttpWebRequest)=value

"""

 ServicePoint=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the service point to use for the request.



Get: ServicePoint(self: HttpWebRequest) -> ServicePoint



"""

 SupportsCookieContainer=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: SupportsCookieContainer(self: HttpWebRequest) -> bool



"""

 Timeout=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the time-out value in milliseconds for the System.Net.HttpWebRequest.GetResponse and System.Net.HttpWebRequest.GetRequestStream methods.



Get: Timeout(self: HttpWebRequest) -> int



Set: Timeout(self: HttpWebRequest)=value

"""

 TransferEncoding=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the value of the Transfer-encoding HTTP header.



Get: TransferEncoding(self: HttpWebRequest) -> str



Set: TransferEncoding(self: HttpWebRequest)=value

"""

 UnsafeAuthenticatedConnectionSharing=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value that indicates whether to allow high-speed NTLM-authenticated connection sharing.



Get: UnsafeAuthenticatedConnectionSharing(self: HttpWebRequest) -> bool



Set: UnsafeAuthenticatedConnectionSharing(self: HttpWebRequest)=value

"""

 UseDefaultCredentials=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a System.Boolean value that controls whether default credentials are sent with requests.



Get: UseDefaultCredentials(self: HttpWebRequest) -> bool



Set: UseDefaultCredentials(self: HttpWebRequest)=value

"""

 UserAgent=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the value of the User-agent HTTP header.



Get: UserAgent(self: HttpWebRequest) -> str



Set: UserAgent(self: HttpWebRequest)=value

"""


 DefaultCachePolicy=None
 DefaultMaximumErrorResponseLength=64
 DefaultMaximumResponseHeadersLength=64




class DragStartedEventArgs(RoutedEventArgs):
 """
 Provides information about the System.Windows.Controls.Primitives.Thumb.DragStarted event that occurs when a user drags a System.Windows.Controls.Primitives.Thumb control with the mouse..

 

 DragStartedEventArgs(horizontalOffset: float,verticalOffset: float)
 """
 @staticmethod
 def __new__(self,horizontalOffset,verticalOffset):
  """ __new__(cls: type,horizontalOffset: float,verticalOffset: float) """
  pass
 HorizontalOffset=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the horizontal offset of the mouse click relative to the screen coordinates of the System.Windows.Controls.Primitives.Thumb.



Get: HorizontalOffset(self: DragStartedEventArgs) -> float



"""

 VerticalOffset=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the vertical offset of the mouse click relative to the screen coordinates of the System.Windows.Controls.Primitives.Thumb.



Get: VerticalOffset(self: DragStartedEventArgs) -> float



"""





class Icon(MarshalByRefObject,ISerializable,ICloneable,IDisposable):
 """
 Represents a Windows icon,which is a small bitmap image that is used to represent an object. Icons can be thought of as transparent bitmaps,although their size is determined by the system.

 

 Icon(original: Icon,size: Size)

 Icon(original: Icon,width: int,height: int)

 Icon(type: Type,resource: str)

 Icon(stream: Stream)

 Icon(stream: Stream,width: int,height: int)

 Icon(fileName: str)

 Icon(fileName: str,size: Size)

 Icon(fileName: str,width: int,height: int)

 Icon(stream: Stream,size: Size)
 """
 def Clone(self):
  """
  Clone(self: Icon) -> object

  

   Clones the System.Drawing.Icon,creating a duplicate image.

   Returns: An object that can be cast to an System.Drawing.Icon.
  """
  pass
 def Dispose(self):
  """
  Dispose(self: Icon)

   Releases all resources used by this System.Drawing.Icon.
  """
  pass
 @staticmethod
 def ExtractAssociatedIcon(filePath):
  """
  ExtractAssociatedIcon(filePath: str) -> Icon

  

   Returns an icon representation of an image that is contained in the specified file.

  

   filePath: The path to the file that contains an image.

   Returns: The System.Drawing.Icon representation of the image that is contained in the specified file.
  """
  pass
 @staticmethod
 def FromHandle(handle):
  """
  FromHandle(handle: IntPtr) -> Icon

  

   Creates a GDI+ System.Drawing.Icon from the specified Windows handle to an icon (HICON).

  

   handle: A Windows handle to an icon.

   Returns: The System.Drawing.Icon this method creates.
  """
  pass
 def MemberwiseClone(self,*args):
  """
  MemberwiseClone(self: MarshalByRefObject,cloneIdentity: bool) -> MarshalByRefObject

  

   Creates a shallow copy of the current System.MarshalByRefObject object.

  

   cloneIdentity: false to delete the current System.MarshalByRefObject object's identity,which will cause the 

    object to be assigned a new identity when it is marshaled across a remoting boundary. A value of 

    false is usually appropriate. true to copy the current System.MarshalByRefObject object's 

    identity to its clone,which will cause remoting client calls to be routed to the remote server 

    object.

  

   Returns: A shallow copy of the current System.MarshalByRefObject object.

  MemberwiseClone(self: object) -> object

  

   Creates a shallow copy of the current System.Object.

   Returns: A shallow copy of the current System.Object.
  """
  pass
 def Save(self,outputStream):
  """
  Save(self: Icon,outputStream: Stream)

   Saves this System.Drawing.Icon to the specified output System.IO.Stream.

  

   outputStream: The System.IO.Stream to save to.
  """
  pass
 def ToBitmap(self):
  """
  ToBitmap(self: Icon) -> Bitmap

  

   Converts this System.Drawing.Icon to a GDI+ System.Drawing.Bitmap.

   Returns: A System.Drawing.Bitmap that represents the converted System.Drawing.Icon.
  """
  pass
 def ToString(self):
  """
  ToString(self: Icon) -> str

  

   Gets a human-readable string that describes the System.Drawing.Icon.

   Returns: A string that describes the System.Drawing.Icon.
  """
  pass
 def __enter__(self,*args):
  """
  __enter__(self: IDisposable) -> object

  

   Provides the implementation of __enter__ for objects which implement IDisposable.
  """
  pass
 def __exit__(self,*args):
  """
  __exit__(self: IDisposable,exc_type: object,exc_value: object,exc_back: object)

   Provides the implementation of __exit__ for objects which implement IDisposable.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,*__args):
  """
  __new__(cls: type,fileName: str)

  __new__(cls: type,fileName: str,size: Size)

  __new__(cls: type,fileName: str,width: int,height: int)

  __new__(cls: type,original: Icon,size: Size)

  __new__(cls: type,original: Icon,width: int,height: int)

  __new__(cls: type,type: Type,resource: str)

  __new__(cls: type,stream: Stream)

  __new__(cls: type,stream: Stream,size: Size)

  __new__(cls: type,stream: Stream,width: int,height: int)
  """
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Handle=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the Windows handle for this System.Drawing.Icon. This is not a copy of the handle; do not free it.



Get: Handle(self: Icon) -> IntPtr



"""

 Height=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the height of this System.Drawing.Icon.



Get: Height(self: Icon) -> int



"""

 Size=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the size of this System.Drawing.Icon.



Get: Size(self: Icon) -> Size



"""

 Width=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the width of this System.Drawing.Icon.



Get: Width(self: Icon) -> int



"""





class TYPEFLAGS(Enum,IComparable,IFormattable,IConvertible):
 """
 Use System.Runtime.InteropServices.ComTypes.TYPEFLAGS instead.

 

 enum (flags) TYPEFLAGS,values: TYPEFLAG_FAGGREGATABLE (1024),TYPEFLAG_FAPPOBJECT (1),TYPEFLAG_FCANCREATE (2),TYPEFLAG_FCONTROL (32),TYPEFLAG_FDISPATCHABLE (4096),TYPEFLAG_FDUAL (64),TYPEFLAG_FHIDDEN (16),TYPEFLAG_FLICENSED (4),TYPEFLAG_FNONEXTENSIBLE (128),TYPEFLAG_FOLEAUTOMATION (256),TYPEFLAG_FPREDECLID (8),TYPEFLAG_FPROXY (16384),TYPEFLAG_FREPLACEABLE (2048),TYPEFLAG_FRESTRICTED (512),TYPEFLAG_FREVERSEBIND (8192)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 TYPEFLAG_FAGGREGATABLE=None
 TYPEFLAG_FAPPOBJECT=None
 TYPEFLAG_FCANCREATE=None
 TYPEFLAG_FCONTROL=None
 TYPEFLAG_FDISPATCHABLE=None
 TYPEFLAG_FDUAL=None
 TYPEFLAG_FHIDDEN=None
 TYPEFLAG_FLICENSED=None
 TYPEFLAG_FNONEXTENSIBLE=None
 TYPEFLAG_FOLEAUTOMATION=None
 TYPEFLAG_FPREDECLID=None
 TYPEFLAG_FPROXY=None
 TYPEFLAG_FREPLACEABLE=None
 TYPEFLAG_FRESTRICTED=None
 TYPEFLAG_FREVERSEBIND=None
 value__=None

